% Auto-generated chapter 11 for nasai
% Hadiths in this chapter: 153

\hadithdefcmd{nasai}{876}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ عَيَّاشٍ، قَالَ حَدَّثَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي سَالِمٌ، ح وَأَخْبَرَنِي أَحْمَدُ بْنُ مُحَمَّدِ بْنِ الْمُغِيرَةِ، قَالَ حَدَّثَنَا عُثْمَانُ، - هُوَ ابْنُ سَعِيدٍ - عَنْ شُعَيْبٍ، عَنْ مُحَمَّدٍ، - وَهُوَ الزُّهْرِيُّ - قَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنِ ابْنِ عُمَرَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم إِذَا افْتَتَحَ التَّكْبِيرَ فِي الصَّلاَةِ رَفَعَ يَدَيْهِ حِينَ يُكَبِّرُ حَتَّى يَجْعَلَهُمَا حَذْوَ مَنْكِبَيْهِ وَإِذَا كَبَّرَ لِلرُّكُوعِ فَعَلَ مِثْلَ ذَلِكَ ثُمَّ إِذَا قَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ فَعَلَ مِثْلَ ذَلِكَ وَقَالَ ‏"‏ رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏ ‏.‏ وَلاَ يَفْعَلُ ذَلِكَ حِينَ يَسْجُدُ وَلاَ حِينَ يَرْفَعُ رَأْسَهُ مِنَ السُّجُودِ ‏.‏\hadithno{876}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn Umar said:I saw the Messenger of Allah (ﷺ) when he said the opening Takbir of the prayer, raise his hands until they were level with his shoulders. When he said the Takbir before bowing he did likewise, and when he said: 'Sami Allahu liman hamidah (Allah hears those who praise Him),' he did likewise, then he said: 'Rabbana wa lakal-hamd (Our Lord, to You be praise).' But he did not do that when he prostrated or when he raised his head from prostration}}
\hadithdefcmd{nasai}{877}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَالِمٌ، عَنِ ابْنِ عُمَرَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم إِذَا قَامَ إِلَى الصَّلاَةِ رَفَعَ يَدَيْهِ حَتَّى تَكُونَا حَذْوَ مَنْكِبَيْهِ ثُمَّ يُكَبِّرُ - قَالَ - وَكَانَ يَفْعَلُ ذَلِكَ حِينَ يُكَبِّرُ لِلرُّكُوعِ وَيَفْعَلُ ذَلِكَ حِينَ يَرْفَعُ رَأْسَهُ مِنَ الرُّكُوعِ وَيَقُولُ ‏ "‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ وَلاَ يَفْعَلُ ذَلِكَ فِي السُّجُودِ ‏.‏\hadithno{877}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn Umar said:"I saw the Messenger of Allah (ﷺ), when he stood to pray, raise his hands until they were in level with his shoulders, then he said the takbir. He did that when he said the Takbir before bowing, and he did that when he raised his head from bowing and said: 'Sami Allahu liman hamidah (Allah hears those who praise Him).' Bu he did not do that during the prostration}}
\hadithdefcmd{nasai}{878}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا افْتَتَحَ الصَّلاَةَ رَفَعَ يَدَيْهِ حَذْوَ مَنْكِبَيْهِ وَإِذَا رَكَعَ وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ رَفَعَهُمَا كَذَلِكَ وَقَالَ ‏ "‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏ ‏.‏ وَكَانَ لاَ يَفْعَلُ ذَلِكَ فِي السُّجُودِ ‏.‏\hadithno{878}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abdullah bin Umar :that when the Messenger of Allah (ﷺ) started to pray, he would raise his hands in level with his shoulders, and when he bowed and when he raised his head from bowing, he would raise them likewise and say "Sami Allahu liman hamidah, Rabbana wa lakal-hamd (Allah hears those who praise Him, our Lord, to You be praise." And he did not do that when he prostrated)}}
\hadithdefcmd{nasai}{879}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ الْجَبَّارِ بْنِ وَائِلٍ، عَنْ أَبِيهِ، قَالَ صَلَّيْتُ خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا افْتَتَحَ الصَّلاَةَ كَبَّرَ وَرَفَعَ يَدَيْهِ حَتَّى حَاذَتَا أُذُنَيْهِ ثُمَّ يَقْرَأُ بِفَاتِحَةِ الْكِتَابِ فَلَمَّا فَرَغَ مِنْهَا قَالَ ‏ "‏ آمِينَ ‏"‏ ‏.‏ يَرْفَعُ بِهَا صَوْتَهُ ‏.‏\hadithno{879}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abdul-Jabbar bin Wa'il that his father said:"I prayed behind the Messenger of Allah (ﷺ) and when he started to pray he said the Takbir and raised his hands until they were in level with his ears. Then he recited the Opening of the Book, and when he had finished he said 'Amin' and raised his voice with it}}
\hadithdefcmd{nasai}{880}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ نَصْرَ بْنَ عَاصِمٍ، عَنْ مَالِكِ بْنِ الْحُوَيْرِثِ، وَكَانَ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا صَلَّى رَفَعَ يَدَيْهِ حِينَ يُكَبِّرُ حِيَالَ أُذُنَيْهِ وَإِذَا أَرَادَ أَنْ يَرْكَعَ وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ ‏.‏\hadithno{880}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Malik bin Al-Huwairith- who was one of the companions of the Prophet (ﷺ)- that:When the Messenger of Allah (ﷺ) prayed he would raise his hands-when he said the Takbir- until they were parallel to his ears, and when he wanted to bow and when he raised his head from bowing}}
\hadithdefcmd{nasai}{881}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنِ ابْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ نَصْرِ بْنِ عَاصِمٍ، عَنْ مَالِكِ بْنِ الْحُوَيْرِثِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم حِينَ دَخَلَ فِي الصَّلاَةِ رَفَعَ يَدَيْهِ وَحِينَ رَكَعَ وَحِينَ رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ حَتَّى حَاذَتَا فُرُوعَ أُذُنَيْهِ ‏.‏\hadithno{881}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Malik bin Al-Huwairith said:"I saw the Messenger of Allah (ﷺ), when he started to pray, raise his hands, and when he bowed, and when he raised his head from bowing, until they were parallel with the top of his ears}}
\hadithdefcmd{nasai}{882}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، قَالَ حَدَّثَنَا فِطْرُ بْنُ خَلِيفَةَ، عَنْ عَبْدِ الْجَبَّارِ بْنِ وَائِلٍ، عَنْ أَبِيهِ، أَنَّهُ رَأَى النَّبِيَّ صلى الله عليه وسلم إِذَا افْتَتَحَ الصَّلاَةَ رَفَعَ يَدَيْهِ حَتَّى تَكَادَ إِبْهَامَاهُ تُحَاذِي شَحْمَةَ أُذُنَيْهِ ‏.‏\hadithno{882}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abdul-Jabbar bin Wa'il, from his father, that:He saw the Prophet (ﷺ), when he started to pray, raise his hands until his thumbs were almost level with his earlobes}}
\hadithdefcmd{nasai}{883}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ سَمْعَانَ، قَالَ جَاءَ أَبُو هُرَيْرَةَ إِلَى مَسْجِدِ بَنِي زُرَيْقٍ فَقَالَ ثَلاَثٌ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَعْمَلُ بِهِنَّ تَرَكَهُنَّ النَّاسُ كَانَ يَرْفَعُ يَدَيْهِ فِي الصَّلاَةِ مَدًّا وَيَسْكُتُ هُنَيْهَةً وَيُكَبِّرُ إِذَا سَجَدَ وَإِذَا رَفَعَ ‏.‏\hadithno{883}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Sa'eed bin Sam'an said Abu Hurairah came to the Masjid of Banu Zuraiq and said:"There are three things that the Messenger of Allah (ﷺ) used to do and the people have abandoned; he used to raise his hands extended when praying, and he would fall silent briefly, and say takbir when he prostrated and when he sat up}}
\hadithdefcmd{nasai}{884}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ الْمَسْجِدَ فَدَخَلَ رَجُلٌ فَصَلَّى ثُمَّ جَاءَ فَسَلَّمَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَرَدَّ عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ ارْجِعْ فَصَلِّ فَإِنَّكَ لَمْ تُصَلِّ ‏"‏ ‏.‏ فَرَجَعَ فَصَلَّى كَمَا صَلَّى ثُمَّ جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَسَلَّمَ عَلَيْهِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَعَلَيْكَ السَّلاَمُ ارْجِعْ فَصَلِّ فَإِنَّكَ لَمْ تُصَلِّ ‏"‏ ‏.‏ فَعَلَ ذَلِكَ ثَلاَثَ مَرَّاتٍ فَقَالَ الرَّجُلُ وَالَّذِي بَعَثَكَ بِالْحَقِّ مَا أُحْسِنُ غَيْرَ هَذَا فَعَلِّمْنِي ‏.‏ قَالَ ‏"‏ إِذَا قُمْتَ إِلَى الصَّلاَةِ فَكَبِّرْ ثُمَّ اقْرَأْ مَا تَيَسَّرَ مَعَكَ مِنَ الْقُرْآنِ ثُمَّ ارْكَعْ حَتَّى تَطْمَئِنَّ رَاكِعًا ثُمَّ ارْفَعْ حَتَّى تَعْتَدِلَ قَائِمًا ثُمَّ اسْجُدْ حَتَّى تَطْمَئِنَّ سَاجِدًا ثُمَّ ارْفَعْ حَتَّى تَطْمَئِنَّ جَالِسًا ثُمَّ افْعَلْ ذَلِكَ فِي صَلاَتِكَ كُلِّهَا ‏"‏ ‏.‏\hadithno{884}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah (ﷺ) entered the Masjid, then a man entered and prayed, then he came and greeted the Messenger of Allah (ﷺ) with Salam. The Messenger of Allah (ﷺ) returned his greeting and said: Go back and pray, for you have not prayed." So he went back and prayed as he has prayed before, then he came to the Prophet (ﷺ) and greeted him with Salam, and the Messenger of Allah (ﷺ) said to him: "Wa alaika as-salam (and upon you be peace). Go back and pray for you have not prayed." He did that three times, then the man said: "By the One Who sent you with the truth, I cannot do any better than that; teach me." He said: "When you stand to pray, say the Takbir, then recite whatever is easy for you of Quran. Then bow until you have tranquility in your bowing, then stand up until you are standing straight. Then prostrate until you have tranquility in your prostration, then sit up until you have tranquility in your sitting. Then do that throughout your entire prayer}}
\hadithdefcmd{nasai}{885}{أَخْبَرَنِي مُحَمَّدُ بْنُ وَهْبٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ أَبِي عَبْدِ الرَّحِيمِ، قَالَ حَدَّثَنِي زَيْدٌ، - هُوَ ابْنُ أَبِي أُنَيْسَةَ - عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَوْنِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ قَامَ رَجُلٌ خَلْفَ نَبِيِّ اللَّهِ صلى الله عليه وسلم فَقَالَ اللَّهُ أَكْبَرُ كَبِيرًا وَالْحَمْدُ لِلَّهِ كَثِيرًا وَسُبْحَانَ اللَّهِ بُكْرَةً وَأَصِيلاً ‏.‏ فَقَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ صَاحِبُ الْكَلِمَةِ ‏"‏ فَقَالَ رَجُلٌ أَنَا يَا نَبِيَّ اللَّهِ ‏.‏ فَقَالَ ‏"‏ لَقَدِ ابْتَدَرَهَا اثْنَا عَشَرَ مَلَكًا ‏"‏ ‏.‏\hadithno{885}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abdullah bin Umar that:A man stood behind the Prophet of Allah (ﷺ) and said: "Allahu Akbaru kabira wal-hamdu Lillahi kathira, wa subhan-Allahi bukratan was asila (Allah is Most Great and much praise be to Allah and glorified be Allah at the beginning and end of the day)." The Prophet of Allah (ﷺ) said: "Who spoke these words?" A man said: "I did, O Prophet of Allah (SWT)." He said: "Twelve angels rushed (to take them up)}}
\hadithdefcmd{nasai}{886}{أَخْبَرَنَا مُحَمَّدُ بْنُ شُجَاعٍ الْمَرُّوذِيُّ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ حَجَّاجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ عَوْنِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عُمَرَ، قَالَ بَيْنَمَا نَحْنُ نُصَلِّي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَجُلٌ مِنَ الْقَوْمِ اللَّهُ أَكْبَرُ كَبِيرًا وَالْحَمْدُ لِلَّهِ كَثِيرًا وَسُبْحَانَ اللَّهِ بُكْرَةً وَأَصِيلاً ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنِ الْقَائِلُ كَلِمَةَ كَذَا وَكَذَا ‏"‏ ‏.‏ فَقَالَ رَجُلٌ مِنَ الْقَوْمِ أَنَا يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ عَجِبْتُ لَهَا ‏"‏ ‏.‏ وَذَكَرَ كَلِمَةً مَعْنَاهَا ‏"‏ فُتِحَتْ لَهَا أَبْوَابُ السَّمَاءِ ‏"‏ ‏.‏ قَالَ ابْنُ عُمَرَ مَا تَرَكْتُهُ مُنْذُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُهُ ‏.‏\hadithno{886}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn Umar said:"While we were praying with the Messenger of Allah (ﷺ), a man among the people said: 'Allahu Akbaru kabira, wal-hamdu Lillahi kathira, wa subhan-Allahi bukratan was asila (Allah is Most Great and much praise be to Allah and glorified be Allah at the beginning and end of the day).' The Messenger of Allah (ﷺ) said: 'Who is the one who said such and such?' A man among the people said: 'I did, O Messenger of Allah.' He said: ' I like it,' and he said words to the effect that the gates of the Heavens had been opened for it." Ibn Umar said: "I never stopped saying it since I heard the Messenger of Allah (ﷺ) say that}}
\hadithdefcmd{nasai}{887}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ مُوسَى بْنِ عُمَيْرٍ الْعَنْبَرِيِّ، وَقَيْسِ بْنِ سُلَيْمٍ الْعَنْبَرِيِّ، قَالاَ حَدَّثَنَا عَلْقَمَةُ بْنُ وَائِلٍ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم إِذَا كَانَ قَائِمًا فِي الصَّلاَةِ قَبَضَ بِيَمِينِهِ عَلَى شِمَالِهِ ‏.‏\hadithno{887}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Musa bin Umair Al-Anbari and Qais bin Sulaim Al-Anbari said:"Alqamah bin Wa'il told us that his father said: "I saw the Messenger of Allah (ﷺ), when he was standing in prayer, holding his left hand with his right}}
\hadithdefcmd{nasai}{888}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا هُشَيْمٌ، عَنِ الْحَجَّاجِ بْنِ أَبِي زَيْنَبَ، قَالَ سَمِعْتُ أَبَا عُثْمَانَ، يُحَدِّثُ عَنِ ابْنِ مَسْعُودٍ، قَالَ رَآنِي النَّبِيُّ صلى الله عليه وسلم وَقَدْ وَضَعْتُ شِمَالِي عَلَى يَمِينِي فِي الصَّلاَةِ فَأَخَذَ بِيَمِينِي فَوَضَعَهَا عَلَى شِمَالِي ‏.‏\hadithno{888}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Al Hajjaj bin Abi Zainab said:X"I heard Abu Uthman narrate that Ibn Mas'ud said: 'The Prophet (ﷺ) saw me when I had placed my left hand on my right in prayer. He took hold of my right hand and placed it on my left}}
\hadithdefcmd{nasai}{889}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ زَائِدَةَ، قَالَ حَدَّثَنَا عَاصِمُ بْنُ كُلَيْبٍ، قَالَ حَدَّثَنِي أَبِي أَنَّ وَائِلَ بْنَ حُجْرٍ، أَخْبَرَهُ قَالَ قُلْتُ لأَنْظُرَنَّ إِلَى صَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم كَيْفَ يُصَلِّي فَنَظَرْتُ إِلَيْهِ فَقَامَ فَكَبَّرَ وَرَفَعَ يَدَيْهِ حَتَّى حَاذَتَا بِأُذُنَيْهِ ثُمَّ وَضَعَ يَدَهُ الْيُمْنَى عَلَى كَفِّهِ الْيُسْرَى وَالرُّسْغِ وَالسَّاعِدِ فَلَمَّا أَرَادَ أَنْ يَرْكَعَ رَفَعَ يَدَيْهِ مِثْلَهَا - قَالَ - وَوَضَعَ يَدَيْهِ عَلَى رُكْبَتَيْهِ ثُمَّ لَمَّا رَفَعَ رَأْسَهُ رَفَعَ يَدَيْهِ مِثْلَهَا ثُمَّ سَجَدَ فَجَعَلَ كَفَّيْهِ بِحِذَاءِ أُذُنَيْهِ ثُمَّ قَعَدَ وَافْتَرَشَ رِجْلَهُ الْيُسْرَى وَوَضَعَ كَفَّهُ الْيُسْرَى عَلَى فَخِذِهِ وَرُكْبَتِهِ الْيُسْرَى وَجَعَلَ حَدَّ مِرْفَقِهِ الأَيْمَنِ عَلَى فَخِذِهِ الْيُمْنَى ثُمَّ قَبَضَ اثْنَتَيْنِ مِنْ أَصَابِعِهِ وَحَلَّقَ حَلْقَةً ثُمَّ رَفَعَ إِصْبَعَهُ فَرَأَيْتُهُ يُحَرِّكُهَا يَدْعُو بِهَا ‏.‏\hadithno{889}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Wa'il bin Hujr said:"I said: 'I am going to watch how the Messenger of Allah (ﷺ) prays.' So I watched him and he stood and said the takbir, and raised his hands until they were in the level with his ears, then he placed his right hand over his left hand, wrist and lower forearm. When he wanted to bow he raised his hands likewise. Then he prostrated and placed his hands in level with his ears. Then he sat up and placed his left leg under him; he put his left hand on his left thigh and knee, and he put the edge of his right elbow on his right thigh, then he held two of his fingers together and made a circle, and raised his forefinger, and I saw him moving it and supplicating with it}}
\hadithdefcmd{nasai}{890}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ هِشَامٍ، ح وَأَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، - وَاللَّفْظُ لَهُ - عَنْ هِشَامٍ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى أَنْ يُصَلِّيَ الرَّجُلُ مُخْتَصِرًا ‏.‏\hadithno{890}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet (ﷺ) forbade praying with one's hands on one's waist}}
\hadithdefcmd{nasai}{891}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ سُفْيَانَ بْنِ حَبِيبٍ، عَنْ سَعِيدِ بْنِ زِيَادٍ، عَنْ زِيَادِ بْنِ صُبَيْحٍ، قَالَ صَلَّيْتُ إِلَى جَنْبِ ابْنِ عُمَرَ فَوَضَعْتُ يَدِي عَلَى خَصْرِي فَقَالَ لِي هَكَذَا ضَرْبَةً بِيَدِهِ فَلَمَّا صَلَّيْتُ قُلْتُ لِرَجُلٍ مَنْ هَذَا قَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ ‏.‏ قُلْتُ يَا أَبَا عَبْدِ الرَّحْمَنِ مَا رَابَكَ مِنِّي قَالَ إِنَّ هَذَا الصَّلْبُ وَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَانَا عَنْهُ ‏.‏\hadithno{891}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ziyad bin Subaih said:"I prayed beside Ibn Umar and put my hand on my waist, and he did this to me-knocked it with his hand. When I had finished praying I said to a man: 'Who is this?' He said: "Abdullah bin Umar.' I said: 'O Abu Abdur-Rahman, why are you angry with me?' He said: 'This is the posture of crucifixion, and the Mesenger of Allah (ﷺ) forbade us to do this}}
\hadithdefcmd{nasai}{892}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ بْنِ سَعِيدٍ الثَّوْرِيِّ، عَنْ مَيْسَرَةَ، عَنِ الْمِنْهَالِ بْنِ عَمْرٍو، عَنْ أَبِي عُبَيْدَةَ، أَنَّ عَبْدَ اللَّهِ، رَأَى رَجُلاً يُصَلِّي قَدْ صَفَّ بَيْنَ قَدَمَيْهِ فَقَالَ خَالَفَ السُّنَّةَ وَلَوْ رَاوَحَ بَيْنَهُمَا كَانَ أَفْضَلَ ‏.‏\hadithno{892}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Ubaidah that:Abdullah saw a man who was praying with his feet together. He said: "He is going against the Sunnah; if he shifted his weight from one to the other that would be better}}
\hadithdefcmd{nasai}{893}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، قَالَ أَخْبَرَنِي مَيْسَرَةُ بْنُ حَبِيبٍ، قَالَ سَمِعْتُ الْمِنْهَالَ بْنَ عَمْرٍو، يُحَدِّثُ عَنْ أَبِي عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ، أَنَّهُ رَأَى رَجُلاً يُصَلِّي قَدْ صَفَّ بَيْنَ قَدَمَيْهِ فَقَالَ أَخْطَأَ السُّنَّةَ وَلَوْ رَاوَحَ بَيْنَهُمَا كَانَ أَعْجَبَ إِلَىَّ ‏.‏\hadithno{893}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abdullah that:He saw a man praying with his feet together. He said: "He is not following the Sunnah. If he were to shift his weight from one to the other I would like that better}}
\hadithdefcmd{nasai}{894}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَتْ لَهُ سَكْتَةٌ إِذَا افْتَتَحَ الصَّلاَةَ ‏.‏\hadithno{894}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah (ﷺ) used to pause briefly when he had started to pray}}
\hadithdefcmd{nasai}{895}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا افْتَتَحَ الصَّلاَةَ سَكَتَ هُنَيْهَةً فَقُلْتُ بِأَبِي أَنْتَ وَأُمِّي يَا رَسُولَ اللَّهِ مَا تَقُولُ فِي سُكُوتِكَ بَيْنَ التَّكْبِيرِ وَالْقِرَاءَةِ قَالَ ‏ "‏ أَقُولُ اللَّهُمَّ بَاعِدْ بَيْنِي وَبَيْنَ خَطَايَاىَ كَمَا بَاعَدْتَ بَيْنَ الْمَشْرِقِ وَالْمَغْرِبِ اللَّهُمَّ نَقِّنِي مِنْ خَطَايَاىَ كَمَا يُنَقَّى الثَّوْبُ الأَبْيَضُ مِنَ الدَّنَسِ اللَّهُمَّ اغْسِلْنِي مِنْ خَطَايَاىَ بِالْمَاءِ وَالثَّلْجِ وَالْبَرَدِ ‏"‏ ‏.‏\hadithno{895}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"When the Messenger of Allah (ﷺ) started to pray he would pause briefly. I said: 'May my father and mother be ransomed for you, O Messenger of Allah, what do you say when you pause briefly between the takbir and reciation?' He said: 'I say: Allahuma ba'id bayni wa bayna khatayaya kama ba'adta bayna al-mashriqi wal-maghrib; Allahumma naqqini min khatayaya kama yunaqqa ath-thawb al-abyad min ad-danas; Allahumma ighsilni min khatayaya bil ma'i wa ath-thalji wal-barad. (O Allah, put a great distance between me and my sins, as great as the distance You have made between the East and the West; O Allah, cleanse me of my sins as a white garment is cleansed from filth; O Allah, wash away my sins with water and snow and hail)}}
\hadithdefcmd{nasai}{896}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدٍ، قَالَ حَدَّثَنَا شُرَيْحُ بْنُ يَزِيدَ الْحَضْرَمِيُّ، قَالَ أَخْبَرَنِي شُعَيْبُ بْنُ أَبِي حَمْزَةَ، قَالَ أَخْبَرَنِي مُحَمَّدُ بْنُ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا اسْتَفْتَحَ الصَّلاَةَ كَبَّرَ ثُمَّ قَالَ ‏ "‏ إِنَّ صَلاَتِي وَنُسُكِي وَمَحْيَاىَ وَمَمَاتِي لِلَّهِ رَبِّ الْعَالَمِينَ لاَ شَرِيكَ لَهُ وَبِذَلِكَ أُمِرْتُ وَأَنَا مِنَ الْمُسْلِمِينَ اللَّهُمَّ اهْدِنِي لأَحْسَنِ الأَعْمَالِ وَأَحْسَنِ الأَخْلاَقِ لاَ يَهْدِي لأَحْسَنِهَا إِلاَّ أَنْتَ وَقِنِي سَيِّئَ الأَعْمَالِ وَسَيِّئَ الأَخْلاَقِ لاَ يَقِي سَيِّئَهَا إِلاَّ أَنْتَ ‏"‏ ‏.‏\hadithno{896}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Jabir bin Abdullah said:"When the Prophet (ﷺ) started to pray, he would say the takbir, then say: 'Inna salati wa nusuki wa mahyaya wa mamati lillahi rabbil-alamin, la sharika lahu, wa bidhalika umirtu wa ana min al-muslimin. Allahummahdini liahsanil-amali wa ahsanil-akhlaqi la yahdi li ahsaniha illa anta wa qini sayy'al-a'mali wa sayy'al-ahaqi la yaqi sayy'aha illa ant. (Indeed my salah (prayer), my sacrifice, my living, and my dying are for Allah, the Lord of all that exists. He has no partner. And of this I have been commanded, and I am one of the Muslims. O Allah, guide me to the best of deeds and the best of manners, for none can guide to the best of them but You. And protect me from bad deeds and bad manners, for none can protect against them but You}}
\hadithdefcmd{nasai}{897}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ، قَالَ حَدَّثَنِي عَمِّي الْمَاجِشُونُ بْنُ أَبِي سَلَمَةَ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، عَنْ عَلِيٍّ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا اسْتَفْتَحَ الصَّلاَةَ كَبَّرَ ثُمَّ قَالَ ‏ "‏ وَجَّهْتُ وَجْهِيَ لِلَّذِي فَطَرَ السَّمَوَاتِ وَالأَرْضَ حَنِيفًا وَمَا أَنَا مِنَ الْمُشْرِكِينَ إِنَّ صَلاَتِي وَنُسُكِي وَمَحْيَاىَ وَمَمَاتِي لِلَّهِ رَبِّ الْعَالَمِينَ لاَ شَرِيكَ لَهُ وَبِذَلِكَ أُمِرْتُ وَأَنَا مِنَ الْمُسْلِمِينَ اللَّهُمَّ أَنْتَ الْمَلِكُ لاَ إِلَهَ إِلاَّ أَنْتَ أَنَا عَبْدُكَ ظَلَمْتُ نَفْسِي وَاعْتَرَفْتُ بِذَنْبِي فَاغْفِرْ لِي ذُنُوبِي جَمِيعًا لاَ يَغْفِرُ الذُّنُوبَ إِلاَّ أَنْتَ وَاهْدِنِي لأَحْسَنِ الأَخْلاَقِ لاَ يَهْدِي لأَحْسَنِهَا إِلاَّ أَنْتَ وَاصْرِفْ عَنِّي سَيِّئَهَا لاَ يَصْرِفُ عَنِّي سَيِّئَهَا إِلاَّ أَنْتَ لَبَّيْكَ وَسَعْدَيْكَ وَالْخَيْرُ كُلُّهُ فِي يَدَيْكَ وَالشَّرُّ لَيْسَ إِلَيْكَ أَنَا بِكَ وَإِلَيْكَ تَبَارَكْتَ وَتَعَالَيْتَ أَسْتَغْفِرُكَ وَأَتُوبُ إِلَيْكَ ‏"‏ ‏.‏\hadithno{897}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ali, may Allah be pleased with him, that:When the Messenger of Allah (ﷺ) started to pray, he would say Takbir, then say: "Wajahtu wajhi lilladhi fataras-samawatiwal-arda hanifan wa ma ana minal-mushrikin. Inna salati wa nusuki wa mahyaya wa mamati lillahi rabbil-alamin, la sharika lahu, wa bidhalika umirtu wa ana min al-muslimin. Allahumma! Antal-maliku la ilaha illa ant, ana abduka zalamtu nafsi wa'taraftu bidhanbi faghfirli dhunubi jami'an, la yaghfirudhunuba illa anta, wahdini lihasanil-ahklaqi, la yahdi li ahsaniha illa anta wasrif anni sayy'aha la yasrifu anni sayy'aha illa anta, labaika wa sa'daika, wal-khairu kulluhu fi yadaika wash-sharru laisa ilaika ana bika wa ilaika ana bika wa ilaika tabarkta wa ta'alaita astaghfiruka wa atubu ilaik. (Verily, I have turned my face toward Him who created the Heavens and the Earth hanifa (worhsipping none but Allah Alone), and I am not of the idolaters. Verily, my salah, my sacrifice, my living, and my dying are for Allah, the Lord of the all that exists. He has no partner. And of this I have been commanded, and I am one of the Muslims. O Allah, You are the Sovereign and there is none worthy of worship but You. I am Your slave, I have wronged myself and I acknowledge my sin. Forgive me all my sins for no one forgives sins but You. Guide me to the best of manners for none can guide to the best of them but You. Protect me from bad manners for none can protect against them but You. I am at Your service, all goodness is in Your hands, and evil is not attributed to You. I rely on You and turn to You, blessed and exalted are You, I seek Your forgiveness and repent to You}}
\hadithdefcmd{nasai}{898}{أَخْبَرَنَا يَحْيَى بْنُ عُثْمَانَ الْحِمْصِيُّ، قَالَ حَدَّثَنَا ابْنُ حِمْيَرٍ، قَالَ حَدَّثَنَا شُعَيْبُ بْنُ أَبِي حَمْزَةَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، وَذَكَرَ، آخَرَ قَبْلَهُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ الأَعْرَجِ، عَنْ مُحَمَّدِ بْنِ مَسْلَمَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا قَامَ يُصَلِّي تَطَوُّعًا قَالَ ‏ "‏ اللَّهُ أَكْبَرُ وَجَّهْتُ وَجْهِيَ لِلَّذِي فَطَرَ السَّمَوَاتِ وَالأَرْضَ حَنِيفًا مُسْلِمًا وَمَا أَنَا مِنَ الْمُشْرِكِينَ إِنَّ صَلاَتِي وَنُسُكِي وَمَحْيَاىَ وَمَمَاتِي لِلَّهِ رَبِّ الْعَالَمِينَ لاَ شَرِيكَ لَهُ وَبِذَلِكَ أُمِرْتُ وَأَنَا أَوَّلُ الْمُسْلِمِينَ اللَّهُمَّ أَنْتَ الْمَلِكُ لاَ إِلَهَ إِلاَّ أَنْتَ سُبْحَانَكَ وَبِحَمْدِكَ ‏"‏ ‏.‏ ثُمَّ يَقْرَأُ ‏.‏\hadithno{898}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Muhammad bin Maslamah that:When the Messenger of Allah (ﷺ) stood to offer a voluntary prayer he would say: " Allahu Akbar Wajahtu wajhi lilladhi fataras-samawatiwal-arda hanifan musliman wa ma ana minal-mushrikin. Inna salati wa nusuki wa mahyaya wa mamati lillahi rabbil-alamin, la sharika lahu, wa bidhalika umirtu wa ana awwalul-muslimin. Allahumma antal-maliku la ilaha illa anta subhanaka wa bihamdik (Allah is Most Great. Verily, I have turned my face toward Him who created the Heavens and the Earth hanifa (worhsipping none but Allah Alone), as a Muslim, and I am not of the idolaters. Verily, my Salah, my sacrifice, my living, and my dying are for Allah, the Lord of the all that exists. He has no partner. And of this I have been commanded, and I am the first of the Muslims. O Allah, You are the Sovereign and there is none worthy of worship but You, glory and praise be to You.)" Then he would recite}}
\hadithdefcmd{nasai}{899}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ فَضَالَةَ بْنِ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ عَلِيِّ بْنِ عَلِيٍّ، عَنْ أَبِي الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا افْتَتَحَ الصَّلاَةَ قَالَ ‏ "‏ سُبْحَانَكَ اللَّهُمَّ وَبِحَمْدِكَ تَبَارَكَ اسْمُكَ وَتَعَالَى جَدُّكَ وَلاَ إِلَهَ غَيْرُكَ ‏"‏ ‏.‏\hadithno{899}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Sa'eed that:When the Prophet (ﷺ) started to pray he would say: "Subhanakallahumma, wa bihamdika tabarakasmuka wa ta'ala jadduka wa la ilaha ghairuk (Glory and praise be to You, O Allah. Blessed be Your name and exalted be Your majesty, there is none worthy of worship except You)}}
\hadithdefcmd{nasai}{900}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، قَالَ حَدَّثَنِي جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ عَلِيِّ بْنِ عَلِيٍّ، عَنْ أَبِي الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا افْتَتَحَ الصَّلاَةَ قَالَ ‏ "‏ سُبْحَانَكَ اللَّهُمَّ وَبِحَمْدِكَ وَتَبَارَكَ اسْمُكَ وَتَعَالَى جَدُّكَ وَلاَ إِلَهَ غَيْرُكَ ‏"‏ ‏.‏\hadithno{900}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Sa'eed said:"When the Messenger of Allah (ﷺ) started to pray, he would say: 'Subhanakallahumma, wa bihamdika tabarakasmuka wa ta'ala jadduka wa la ilaha ghairuk (Glory and praise be to You, O Allah. Blessed be Your name and exalted be Your majesty, there is none worthy of worship except You)}}
\hadithdefcmd{nasai}{901}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، وَقَتَادَةَ، وَحُمَيْدٍ، عَنْ أَنَسٍ، أَنَّهُ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي بِنَا إِذْ جَاءَ رَجُلٌ فَدَخَلَ الْمَسْجِدَ وَقَدْ حَفَزَهُ النَّفَسُ فَقَالَ اللَّهُ أَكْبَرُ الْحَمْدُ لِلَّهِ حَمْدًا كَثِيرًا طَيِّبًا مُبَارَكًا فِيهِ ‏.‏ فَلَمَّا قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَتَهُ قَالَ ‏"‏ أَيُّكُمُ الَّذِي تَكَلَّمَ بِكَلِمَاتٍ ‏"‏ فَأَرَمَّ الْقَوْمُ قَالَ ‏"‏ إِنَّهُ لَمْ يَقُلْ بَأْسًا ‏"‏ ‏.‏ قَالَ أَنَا يَا رَسُولَ اللَّهِ جِئْتُ وَقَدْ حَفَزَنِي النَّفَسُ فَقُلْتُهَا ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَقَدْ رَأَيْتُ اثْنَىْ عَشَرَ مَلَكًا يَبْتَدِرُونَهَا أَيُّهُمْ يَرْفَعُهَا ‏"‏ ‏.‏\hadithno{901}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah (ﷺ) was leading us in prayer when a man came and entered the masjid, and he was out of breath. He said: 'Allahu Akbar, al-hamdulillahi hamdan kathiran tayiban mubarakan fih. (Allah is Most Great, praise be to Allah, much good and blessed praise.)' When the Messenger of Allah (ﷺ) had finished his prayer he said: 'Which of you is the one who spoke these words?' The people kept quiet. He said: 'He did not say anything bad.' The man said: 'I did, O Messenger of Allah. I came and I was out of breath, and I said it.' The Prophet (ﷺ) said: 'I saw twelve angels rushing to see which of them would take it up}}
\hadithdefcmd{nasai}{902}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم وَأَبُو بَكْرٍ وَعُمَرُ - رضى الله عنهما - يَسْتَفْتِحُونَ الْقِرَاءَةَ بِـ ‏\{‏ الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ ‏\}‏\hadithno{902}\hadithgrade{Abu Ghuddah: -; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas that:The Prophet (ﷺ), Abu Bakr, and Umar, may Allah be pleased with them both, would start their recitation with: "All the praise and thanks be to Allah, the Lord of all that exists}}
\hadithdefcmd{nasai}{903}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ الزُّهْرِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم وَمَعَ أَبِي بَكْرٍ وَعُمَرَ - رضى الله عنهما - فَافْتَتَحُوا بِـ ‏\{‏ الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ ‏\}‏\hadithno{903}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas:"I prayed with the Prophet (ﷺ) and with Abu Bakr and Umar, may Allah be pleased with them both, and they started with "All the praise and thanks be to Allah, the Lord of all that exists}}
\hadithdefcmd{nasai}{904}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الْمُخْتَارِ بْنِ فُلْفُلٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ بَيْنَمَا ذَاتَ يَوْمٍ بَيْنَ أَظْهُرِنَا - يُرِيدُ النَّبِيَّ صلى الله عليه وسلم - إِذْ أَغْفَى إِغْفَاءَةً ثُمَّ رَفَعَ رَأْسَهُ مُتَبَسِّمًا فَقُلْنَا لَهُ مَا أَضْحَكَكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ نَزَلَتْ عَلَىَّ آنِفًا سُورَةُ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ ‏\{‏ إِنَّا أَعْطَيْنَاكَ الْكَوْثَرَ * فَصَلِّ لِرَبِّكَ وَانْحَرْ * إِنَّ شَانِئَكَ هُوَ الأَبْتَرُ ‏\}‏ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ هَلْ تَدْرُونَ مَا الْكَوْثَرُ ‏"‏ ‏.‏ قُلْنَا اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ ‏"‏ فَإِنَّهُ نَهْرٌ وَعَدَنِيهِ رَبِّي فِي الْجَنَّةِ آنِيَتُهُ أَكْثَرُ مِنْ عَدَدِ الْكَوَاكِبِ تَرِدُهُ عَلَىَّ أُمَّتِي فَيُخْتَلَجُ الْعَبْدُ مِنْهُمْ فَأَقُولُ يَا رَبِّ إِنَّهُ مِنْ أُمَّتِي ‏.‏ فَيَقُولُ لِي إِنَّكَ لاَ تَدْرِي مَا أَحْدَثَ بَعْدَكَ ‏"‏ ‏.‏\hadithno{904}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas in Malik said:"One day when he-the Prophet (ﷺ)- was still among us, he took a nap, then he raised his head, smiling. We said to him: 'Why are you smiling, O Messenger of Allah?' He said: 'Just now this Surah was revealed to me: In the Name of Allah, the Most Gracious, the Most Merciful. Verily, We have granted you (O Muahmmad) Al-Kawthar. Therefore turn in prayer to your Lord and sacrifice (to Him only). For he who hates you, he will be cut off.' Then he said: 'Do you know what Al-Kawthar is?' We said: 'Allah and His Messenger know best.' He said: 'It is a river that my Lord has promised me in Paradise. Its vessels are more than the number of the stars. My Ummah will come to me, then a man among them will be pulled away and I will say: "O Lord, he is one of my Ummah" and He will say to me: 'You do not know what he did after you were gone}}
\hadithdefcmd{nasai}{905}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ شُعَيْبٍ، حَدَّثَنَا اللَّيْثُ، حَدَّثَنَا خَالِدٌ، عَنِ ابْنِ أَبِي هِلاَلٍ، عَنْ نُعَيْمٍ الْمُجْمِرِ، قَالَ صَلَّيْتُ وَرَاءَ أَبِي هُرَيْرَةَ فَقَرَأَ ‏\{‏ بِسْمِ اللَّهِ الرَّحْمَنِ ‏\}‏ الرَّحِيمِ ثُمَّ قَرَأَ بِأُمِّ الْقُرْآنِ حَتَّى إِذَا بَلَغَ ‏\{‏ غَيْرِ الْمَغْضُوبِ عَلَيْهِمْ وَلاَ الضَّالِّينَ ‏\}‏ فَقَالَ آمِينَ ‏.‏ فَقَالَ النَّاسُ آمِينَ ‏.‏ وَيَقُولُ كُلَّمَا سَجَدَ اللَّهُ أَكْبَرُ وَإِذَا قَامَ مِنَ الْجُلُوسِ فِي الاِثْنَيْنِ قَالَ اللَّهُ أَكْبَرُ وَإِذَا سَلَّمَ قَالَ وَالَّذِي نَفْسِي بِيَدِهِ إِنِّي لأَشْبَهُكُمْ صَلاَةً بِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{905}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Nu'aim Al-Mujmir said:"I prayed behind Abu Hurairah and he recited: In the Name of Allah, the Most Gracious, the Most Merciful, then he recited Umm Al-Qur'an (Al Fatihah), and when he reached: not (the way) of those who earned Your anger, nor of those who went astray, he said: 'Amin and the people said 'Amin. And every time he prostrated he said: 'Allahu Akbar and when he stood up from sitting after two Rak'ahs he said: 'Allahu Akbar'. And after he had said the Salam he said: 'By the One in Whose Hand is my soul! My prayer most closely remembers the prayer of the Messenger of Allah}}
\hadithdefcmd{nasai}{906}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَلِيِّ بْنِ الْحَسَنِ بْنِ شَقِيقٍ، قَالَ سَمِعْتُ أَبِي يَقُولُ، أَنْبَأَنَا أَبُو حَمْزَةَ، عَنْ مَنْصُورِ بْنِ زَاذَانَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمْ يُسْمِعْنَا قِرَاءَةَ ‏\{‏ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ ‏\}‏ وَصَلَّى بِنَا أَبُو بَكْرٍ وَعُمَرُ فَلَمْ نَسْمَعْهَا مِنْهُمَا ‏.‏\hadithno{906}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah (ﷺ) led us in prayer, and we did not hear him recite: In the Name of Allah, the Most Gracious, the Most Merciful. And Abu Bakr and Umar led us in prayer and we did not hear it from them either}}
\hadithdefcmd{nasai}{907}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ أَبُو سَعِيدٍ الأَشَجُّ، قَالَ حَدَّثَنِي عُقْبَةُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، وَابْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ صَلَّيْتُ خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ وَعُثْمَانَ - رضى الله عنهم - فَلَمْ أَسْمَعْ أَحَدًا مِنْهُمْ يَجْهَرُ بِـ ‏\{‏ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ ‏\}‏ ‏.‏\hadithno{907}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Muslim}\hadithtrans{It was narrated that Anas said:"I prayed behind the Messenger of Allah (ﷺ), Abu Bakr, Umar and Uthman, may Allah be pleased with them, and I did not hear any of them say out loud: In the Name of Allah, The Most Gracious, The Most Merciful}}
\hadithdefcmd{nasai}{908}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ غِيَاثٍ، قَالَ أَخْبَرَنِي أَبُو نُعَامَةَ الْحَنَفِيُّ، قَالَ حَدَّثَنَا ابْنُ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، قَالَ كَانَ عَبْدُ اللَّهِ بْنُ مُغَفَّلٍ إِذَا سَمِعَ أَحَدَنَا، يَقْرَأُ ‏\{‏ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ ‏\}‏ يَقُولُ صَلَّيْتُ خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَخَلْفَ أَبِي بَكْرٍ وَخَلْفَ عُمَرَ رضى الله عنهما فَمَا سَمِعْتُ أَحَدًا مِنْهُمْ قَرَأَ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ ‏.‏\hadithno{908}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn Abdullah bin Mughaffal said:"If Abdullah bin Mughaffal heard any one of us recite: 'In the Name of Allah, the Most Gracious, the Most Merciful', he would say: 'I prayed behind the Messenger of Allah (ﷺ) and behind Abu Bakr and behind Umar-may Allah be pleased with them both- and I did not hear any of them recite: 'In the Name of Allah, the Most Gracious, the Most Merciful}}
\hadithdefcmd{nasai}{909}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ أَبَا السَّائِبِ، مَوْلَى هِشَامِ بْنِ زُهْرَةَ يَقُولُ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ صَلَّى صَلاَةً لَمْ يَقْرَأْ فِيهَا بِأُمِّ الْقُرْآنِ فَهِيَ خِدَاجٌ هِيَ خِدَاجٌ هِيَ خِدَاجٌ ‏"‏ ‏.‏ غَيْرُ تَمَامٍ ‏.‏ فَقُلْتُ يَا أَبَا هُرَيْرَةَ إِنِّي أَحْيَانًا أَكُونُ وَرَاءَ الإِمَامِ ‏.‏ فَغَمَزَ ذِرَاعِي وَقَالَ اقْرَأْ بِهَا يَا فَارِسِيُّ فِي نَفْسِكَ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ يَقُولُ اللَّهُ عَزَّ وَجَلَّ قَسَمْتُ الصَّلاَةَ بَيْنِي وَبَيْنَ عَبْدِي نِصْفَيْنِ فَنِصْفُهَا لِي وَنِصْفُهَا لِعَبْدِي وَلِعَبْدِي مَا سَأَلَ ‏"‏ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْرَءُوا يَقُولُ الْعَبْدُ ‏\{‏ الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ ‏\}‏ يَقُولُ اللَّهُ عَزَّ وَجَلَّ حَمِدَنِي عَبْدِي ‏.‏ يَقُولُ الْعَبْدُ ‏\{‏ الرَّحْمَنِ الرَّحِيمِ ‏\}‏ يَقُولُ اللَّهُ عَزَّ وَجَلَّ أَثْنَى عَلَىَّ عَبْدِي ‏.‏ يَقُولُ الْعَبْدُ ‏\{‏ مَالِكِ يَوْمِ الدِّينِ ‏\}‏ يَقُولُ اللَّهُ عَزَّ وَجَلَّ مَجَّدَنِي عَبْدِي ‏.‏ يَقُولُ الْعَبْدُ ‏\{‏ إِيَّاكَ نَعْبُدُ وَإِيَّاكَ نَسْتَعِينُ ‏\}‏ فَهَذِهِ الآيَةُ بَيْنِي وَبَيْنَ عَبْدِي وَلِعَبْدِي مَا سَأَلَ ‏.‏ يَقُولُ الْعَبْدُ ‏\{‏ اهْدِنَا الصِّرَاطَ الْمُسْتَقِيمَ * صِرَاطَ الَّذِينَ أَنْعَمْتَ عَلَيْهِمْ غَيْرِ الْمَغْضُوبِ عَلَيْهِمْ وَلاَ الضَّالِّينَ ‏\}‏ فَهَؤُلاَءِ لِعَبْدِي وَلِعَبْدِي مَا سَأَلَ ‏"‏ ‏.‏\hadithno{909}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu As-Sa'ib- the freed slave of Hisham bin Zuhrah-said:"I heard Abu Hurairah say: 'The Messenger of Allah (ﷺ) said: "Whoever offers a prayer in which he does not recite Umm Al-Quran (Al Fatihah), it is deficient, it is deficient, it is deficient, incomplete." I (Abu As-Sa'ib) said: 'O Abu Hurairah, sometimes I am behind the Imam.' He poked me in the arm and said: 'Recite it to yourself, O Persian! For I heard the Messenger of Allah (ﷺ) say: "Allah says: "I have divided prayer between Myself and My slave into two halves, and My slave shall have what he has asked for.'" The Messenger of Allah (ﷺ) said: "Recite, for when the slave says: All the praises and thanks be to Allah, the Lord of all that exists, Allah says: 'My slave has praised Me.' And when he says: The Most Gracious, the Most Merciful, Allah says: 'My slave has extolled Me.' And when he says: The Only Owner (and the Only Ruling Judge) of the Day of Recompense (i.e. the Day of Resurrection), Allah says: 'My slave has glorified Me' . And when he says: You (alone) we worship, and You (alone) we ask for help (for each and everything), He says: 'This is between Me and My slave, and My slave shall have what he has asked for.' And when he says: 'Guide us to the straight way, the way of those on whom You have bestowed Your grace, not (the way) of those who earned Your anger, nor of those who went astray, He says: 'This is for My slave, and My slave shall have what he asked for}}
\hadithdefcmd{nasai}{910}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، عَنْ مَحْمُودِ بْنِ الرَّبِيعِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ صَلاَةَ لِمَنْ لَمْ يَقْرَأْ بِفَاتِحَةِ الْكِتَابِ ‏"‏ ‏.‏\hadithno{910}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ubadah bin As-Samit that :The Prophet (ﷺ) said: "There is no Salah for one who does not recite Fatihatil-Kitab}}
\hadithdefcmd{nasai}{911}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ مَحْمُودِ بْنِ الرَّبِيعِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ صَلاَةَ لِمَنْ لَمْ يَقْرَأْ بِفَاتِحَةِ الْكِتَابِ فَصَاعِدًا ‏"‏ ‏.‏\hadithno{911}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ubadah bin As-Samit said:"The Messenger of Allah (ﷺ) said: "There is no Salah for one who does not recite Fatihatil-Kitab or more}}
\hadithdefcmd{nasai}{912}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ الْمُخَرِّمِيُّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ عَمَّارِ بْنِ رُزَيْقٍ، عَنْ عَبْدِ اللَّهِ بْنِ عِيسَى، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ بَيْنَمَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَعِنْدَهُ جِبْرِيلُ عَلَيْهِ السَّلاَمُ إِذْ سَمِعَ نَقِيضًا فَوْقَهُ فَرَفَعَ جِبْرِيلُ عَلَيْهِ السَّلاَمُ بَصَرَهُ إِلَى السَّمَاءِ فَقَالَ هَذَا بَابٌ قَدْ فُتِحَ مِنَ السَّمَاءِ مَا فُتِحَ قَطُّ ‏.‏ قَالَ فَنَزَلَ مِنْهُ مَلَكٌ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ أَبْشِرْ بِنُورَيْنِ أُوتِيتَهُمَا لَمْ يُؤْتَهُمَا نَبِيٌّ قَبْلَكَ فَاتِحَةِ الْكِتَابِ وَخَوَاتِيمِ سُورَةِ الْبَقَرَةِ لَمْ تَقْرَأْ حَرْفًا مِنْهُمَا إِلاَّ أُعْطِيتَهُ ‏.‏\hadithno{912}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn Abbas said:"When Jibril was with the Messenger of Allah (ﷺ), he heard a sound from above like a door opening. Jibril, peace be upon him, looked up toward the sky and said: 'This is a gate in Heaven that has been opened, but it was never opened before." He said: "An Angel came down from it and came to the Prophet (ﷺ) and said: 'Receive the glad tidings of two lights that have been given to you and were never given to any prophet before you: The Opening of the Book (Al-Fatihah) and the last verses of Surat Al-Baqarah. You will never recite a single letter of them but you will be granted it}}
\hadithdefcmd{nasai}{913}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ سَمِعْتُ حَفْصَ بْنَ عَاصِمٍ، يُحَدِّثُ عَنْ أَبِي سَعِيدِ بْنِ الْمُعَلَّى، أَنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّ بِهِ وَهُوَ يُصَلِّي فَدَعَاهُ - قَالَ - فَصَلَّيْتُ ثُمَّ أَتَيْتُهُ فَقَالَ ‏"‏ مَا مَنَعَكَ أَنْ تُجِيبَنِي ‏"‏ قَالَ كُنْتُ أُصَلِّي ‏.‏ قَالَ ‏"‏ أَلَمْ يَقُلِ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا اسْتَجِيبُوا لِلَّهِ وَلِلرَّسُولِ إِذَا دَعَاكُمْ لِمَا يُحْيِيكُمْ ‏\}‏ أَلاَ أُعَلِّمُكَ أَعْظَمَ سُورَةٍ قَبْلَ أَنْ أَخْرُجَ مِنَ الْمَسْجِدِ ‏"‏ ‏.‏ قَالَ فَذَهَبَ لِيَخْرُجَ قُلْتُ يَا رَسُولَ اللَّهِ قَوْلَكَ ‏.‏ قَالَ ‏"‏ الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ هِيَ السَّبْعُ الْمَثَانِي الَّذِي أُوتِيتُ وَالْقُرْآنُ الْعَظِيمُ ‏"‏ ‏.‏\hadithno{913}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Sa'eed bin Al-Mu'alla that:The Prophet (ﷺ) passed by him when he was praying, and called him. He said: "I finished praying, then I came to him, and he said: 'What kept you from answering me?' He said: 'I was praying.' He said: 'Does not Allah say: O you who believe! Answer Allah (by obeying Him) and (His) Messenger when he calls you to that which will give you life? Shall I not teach you the greatest surah before I leave the masjid?' Then he went to leave, and I said: 'O Messenger of Allah, what about what you said?' He said: "All praise and thanks be to Allah, Lord of all that exists. These are the seven oft-recited that I have been given, and the Grand Quran}}
\hadithdefcmd{nasai}{914}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ عَبْدِ الْحَمِيدِ بْنِ جَعْفَرٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا أَنْزَلَ اللَّهُ عَزَّ وَجَلَّ فِي التَّوْرَاةِ وَلاَ فِي الإِنْجِيلِ مِثْلَ أُمِّ الْقُرْآنِ وَهِيَ السَّبْعُ الْمَثَانِي وَهِيَ مَقْسُومَةٌ بَيْنِي وَبَيْنَ عَبْدِي وَلِعَبْدِي مَا سَأَلَ ‏"‏ ‏.‏\hadithno{914}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ubayy bin Ka'b said:"The Messenger of Allah (ﷺ) said: 'Allah, the Mighty and Sublime, did not reveal in the Tawrah or the Injil anything like Umm Al-Quran (Al-Fatihah), which is the seven oft-recited, and (Allah said) it is divided between Myself and My slave will have what he asked for}}
\hadithdefcmd{nasai}{915}{أَخْبَرَنِي مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أُوتِيَ النَّبِيُّ صلى الله عليه وسلم سَبْعًا مِنَ الْمَثَانِي السَّبْعَ الطُّوَلَ ‏.‏\hadithno{915}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn Abbas said:"The Prophet (ﷺ) was given seven oft-recited; the seven long ones}}
\hadithdefcmd{nasai}{916}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي إِسْحَاقَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، فِي قَوْلِهِ عَزَّ وَجَلَّ ‏\{‏ سَبْعًا مِنَ الْمَثَانِي ‏\}‏ قَالَ السَّبْعُ الطُّوَلُ ‏.‏\hadithno{916}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn Abbas said:Concerning the words of Allah, the Mighty and Sublime: "Seven of Al-Mathani (seven repeatedly-recited): "The seven long ones}}
\hadithdefcmd{nasai}{917}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ صَلَّى النَّبِيُّ صلى الله عليه وسلم الظُّهْرَ فَقَرَأَ رَجُلٌ خَلْفَهُ ‏\{‏ سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى ‏\}‏ فَلَمَّا صَلَّى قَالَ مَنْ قَرَأَ ‏\{‏ سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى ‏\}‏ ‏.‏ قَالَ رَجُلٌ أَنَا ‏.‏ قَالَ ‏"‏ قَدْ عَلِمْتُ أَنَّ بَعْضَكُمْ قَدْ خَالَجَنِيهَا ‏"‏ ‏.‏\hadithno{917}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Imran bin Hussain said:"The Prophet (ﷺ) prayed Zuhr and a man behind him recited: Glorify the Name of your Lord, the Most High. When he had finished praying, he said: 'Who recited: Glorify the Name of your Lord, the Most High?" A man said: 'I did.' He said: 'I realized that some of you were disputing with me over it}}
\hadithdefcmd{nasai}{918}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى صَلاَةَ الظُّهْرِ أَوِ الْعَصْرِ وَرَجُلٌ يَقْرَأُ خَلْفَهُ فَلَمَّا انْصَرَفَ قَالَ ‏"‏ أَيُّكُمْ قَرَأَ بِـ ‏\{‏ سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى ‏\}‏ فَقَالَ رَجُلٌ مِنَ الْقَوْمِ أَنَا وَلَمْ أُرِدْ بِهَا إِلاَّ الْخَيْرَ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ قَدْ عَرَفْتُ أَنَّ بَعْضَكُمْ قَدْ خَالَجَنِيهَا ‏"‏ ‏.‏\hadithno{918}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Imran bin Husain that:The Prophet (ﷺ) prayed Zuhr or Asr, and a man was reciting behind him. When he had finished he said: "Which one of you recited: Glorify the Name of your Lord, the Most High?" A man among the people said: "I did, but I did not intend anything but good." The Prophet (ﷺ) said: "I realized that some of you were disputing with me over it}}
\hadithdefcmd{nasai}{919}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ أُكَيْمَةَ اللَّيْثِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم انْصَرَفَ مِنْ صَلاَةٍ جَهَرَ فِيهَا بِالْقِرَاءَةِ فَقَالَ ‏"‏ هَلْ قَرَأَ مَعِي أَحَدٌ مِنْكُمْ آنِفًا ‏"‏ ‏.‏ قَالَ رَجُلٌ نَعَمْ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ إِنِّي أَقُولُ مَا لِي أُنَازَعُ الْقُرْآنَ ‏"‏ ‏.‏ قَالَ فَانْتَهَى النَّاسُ عَنِ الْقِرَاءَةِ فِيمَا جَهَرَ فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْقِرَاءَةِ مِنَ الصَّلاَةِ حِينَ سَمِعُوا ذَلِكَ ‏.‏\hadithno{919}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah:"The Messenger of Allah (ﷺ) finished a prayer in which he recited out loud, then he said: 'Did any one of you recite with me just now?' A man said: 'Yes, O Messenger of Allah.' He said: 'I was wondering what was distracting me in reciting Quran.'" So the people stopped reciting in prayers in which the Messenger of Allah (ﷺ) recited out loud when they heard that}}
\hadithdefcmd{nasai}{920}{أَخْبَرَنَا هِشَامُ بْنُ عَمَّارٍ، عَنْ صَدَقَةَ، عَنْ زَيْدِ بْنِ وَاقِدٍ، عَنْ حَرَامِ بْنِ حَكِيمٍ، عَنْ نَافِعِ بْنِ مَحْمُودِ بْنِ رَبِيعَةَ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بَعْضَ الصَّلَوَاتِ الَّتِي يُجْهَرُ فِيهَا بِالْقِرَاءَةِ فَقَالَ ‏ "‏ لاَ يَقْرَأَنَّ أَحَدٌ مِنْكُمْ إِذَا جَهَرْتُ بِالْقِرَاءَةِ إِلاَّ بِأُمِّ الْقُرْآنِ ‏"‏ ‏.‏\hadithno{920}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ubadah bin As-Samit said:"The Messenger of Allah (ﷺ) led us in one of the prayers in which the recitation is done out loud, and he said: 'None of you should recite when I recite out loud, apart from the Umm Al\_quran (Al Fatihah)}}
\hadithdefcmd{nasai}{921}{أَخْبَرَنَا الْجَارُودُ بْنُ مُعَاذٍ التِّرْمِذِيُّ، قَالَ حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا جُعِلَ الإِمَامُ لِيُؤْتَمَّ بِهِ فَإِذَا كَبَّرَ فَكَبِّرُوا وَإِذَا قَرَأَ فَأَنْصِتُوا وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ فَقُولُوا اللَّهُمَّ رَبَّنَا لَكَ الْحَمْدُ ‏"‏ ‏.‏\hadithno{921}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'The Imam is appointed to be followed, so when he says the takbir, say the takbir, and when he recites, be silent, and when he says: "Sami' Allahu liman hamidah (Allah hears those who praise Him)," say: "Allahumma rabbana lakal-hamd (Our Lord, to You be praise)}}
\hadithdefcmd{nasai}{922}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ سَعْدٍ الأَنْصَارِيُّ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ عَجْلاَنَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا الإِمَامُ لِيُؤْتَمَّ بِهِ فَإِذَا كَبَّرَ فَكَبِّرُوا وَإِذَا قَرَأَ فَأَنْصِتُوا ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ كَانَ الْمُخَرِّمِيُّ يَقُولُ هُوَ ثِقَةٌ يَعْنِي مُحَمَّدَ بْنَ سَعْدٍ الأَنْصَارِيَّ ‏.‏\hadithno{922}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'The Imam is appointed to be followed, so when he says the takbir, say the takbir, and when he recites, be silent}}
\hadithdefcmd{nasai}{923}{أَخْبَرَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، قَالَ حَدَّثَنِي أَبُو الزَّاهِرِيَّةِ، قَالَ حَدَّثَنِي كَثِيرُ بْنُ مُرَّةَ الْحَضْرَمِيُّ، عَنْ أَبِي الدَّرْدَاءِ، سَمِعَهُ يَقُولُ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَفِي كُلِّ صَلاَةٍ قِرَاءَةٌ قَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏ قَالَ رَجُلٌ مِنَ الأَنْصَارِ وَجَبَتْ هَذِهِ ‏.‏ فَالْتَفَتَ إِلَىَّ وَكُنْتُ أَقْرَبَ الْقَوْمِ مِنْهُ فَقَالَ مَا أَرَى الإِمَامَ إِذَا أَمَّ الْقَوْمَ إِلاَّ قَدْ كَفَاهُمْ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم خَطَأٌ إِنَّمَا هُوَ قَوْلُ أَبِي الدَّرْدَاءِ وَلَمْ يُقْرَأْ هَذَا مَعَ الْكِتَابِ ‏.‏\hadithno{923}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Kathir bin Murrah Al-Hadrami narrated that :He heard Abu Ad-Darda say: "The Messenger of Allah (ﷺ) was asked: 'Is there recitation in every prayer?' He said: 'Yes.' A man among the Ansar said: 'Is that obligatory?' He (Abu Ad-Darda) turned to me (Kathir), as I was closest of the people to him, and said: 'I think that if the Imam leads the people, that is sufficient for them}}
\hadithdefcmd{nasai}{924}{أَخْبَرَنَا يُوسُفُ بْنُ عِيسَى، وَمَحْمُودُ بْنُ غَيْلاَنَ، عَنِ الْفَضْلِ بْنِ مُوسَى، قَالَ حَدَّثَنَا مِسْعَرٌ، عَنْ إِبْرَاهِيمَ السَّكْسَكِيِّ، عَنِ ابْنِ أَبِي أَوْفَى، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ إِنِّي لاَ أَسْتَطِيعُ أَنْ آخُذَ شَيْئًا مِنَ الْقُرْآنِ فَعَلِّمْنِي شَيْئًا يُجْزِئْنِي مِنَ الْقُرْآنِ ‏.‏ فَقَالَ ‏ "‏ قُلْ سُبْحَانَ اللَّهِ وَالْحَمْدُ لِلَّهِ وَلاَ إِلَهَ إِلاَّ اللَّهُ وَاللَّهُ أَكْبَرُ وَلاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏"‏ ‏.‏\hadithno{924}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn Abi Awfa said:"A man came to the Prophet (ﷺ) and said: 'I cannot learn anything of the Quran; teach me something that I can say instead of reciting the Quran.' He said: 'Say: SubhanAllah, wal-hamdulilah, wa la illaha ill-Allah, wa Allahu Akbar, wa la hawla wa la quwwata illa Billahil-aliy al-azim (Glory be to Allah, praise be to Allah, there is none worthy of worship except Allah, Allah is Most Great, and there is no power and no strength except with Allah the Exalted and Magnificent)}}
\hadithdefcmd{nasai}{925}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا بَقِيَّةُ، عَنِ الزُّبَيْدِيِّ، قَالَ أَخْبَرَنِي الزُّهْرِيُّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَمَّنَ الْقَارِئُ فَأَمِّنُوا فَإِنَّ الْمَلاَئِكَةَ تُؤَمِّنُ فَمَنْ وَافَقَ تَأْمِينُهُ تَأْمِينَ الْمَلاَئِكَةِ غَفَرَ اللَّهُ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{925}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'When the reciter says Amin, then say: "Amin" too, for the angels say Amin and if a person's Amin coincides with the Amin of the angels, Allah will forgive his previous sins}}
\hadithdefcmd{nasai}{926}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَمَّنَ الْقَارِئُ فَأَمِّنُوا فَإِنَّ الْمَلاَئِكَةَ تُؤَمِّنُ فَمَنْ وَافَقَ تَأْمِينُهُ تَأْمِينَ الْمَلاَئِكَةِ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{926}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet (ﷺ) said: "When the reciter says Amin, then say: "Amin" too, for the angels say Amin and if a person's Amin coincides with the Amin of the angels, Allah will forgive his previous sins}}
\hadithdefcmd{nasai}{927}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنِي مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا ‏"‏ قَالَ الإِمَامُ ‏\{‏ غَيْرِ الْمَغْضُوبِ عَلَيْهِمْ وَلاَ الضَّالِّينَ ‏\}‏ فَقُولُوا آمِينَ فَإِنَّ الْمَلاَئِكَةَ تَقُولُ آمِينَ وَإِنَّ الإِمَامَ يَقُولُ آمِينَ فَمَنْ وَافَقَ تَأْمِينُهُ تَأْمِينَ الْمَلاَئِكَةِ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{927}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'When the Imam says: Not (the way) of those who earned Your anger, nor of those who went astray, say: 'Amin' for the angels say Amin and the Imam says Amin, and if a person's Amin coincides with the Amin of the angels, his previous sins will be forgiven}}
\hadithdefcmd{nasai}{928}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدٍ، وَأَبِي، سَلَمَةَ أَنَّهُمَا أَخْبَرَاهُ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَمَّنَ الإِمَامُ فَأَمِّنُوا فَإِنَّهُ مَنْ وَافَقَ تَأْمِينُهُ تَأْمِينَ الْمَلاَئِكَةِ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{928}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah (ﷺ) said: "When the Imam says Amin, say Amin, for if a person's Amin coincides with the Amin of the angels, his previous sins will be forgiven}}
\hadithdefcmd{nasai}{929}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، - رضى الله عنه - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا قَالَ الإِمَامُ ‏\{‏ غَيْرِ الْمَغْضُوبِ عَلَيْهِمْ وَلاَ الضَّالِّينَ ‏\}‏ فَقُولُوا آمِينَ فَإِنَّهُ مَنْ وَافَقَ قَوْلُهُ قَوْلَ الْمَلاَئِكَةِ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{929}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah, may Allah be pleased with him, that:The Messenger of Allah (ﷺ) said: "When the Imam says: Not (the way) of those who earned Your anger, nor of those who went astray, say: 'Amin,' for if a person's Amin coincides with the Amin of the angels, his previous sins will be forgiven}}
\hadithdefcmd{nasai}{930}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قَالَ أَحَدُكُمْ آمِينَ وَقَالَتِ الْمَلاَئِكَةُ فِي السَّمَاءِ آمِينَ فَوَافَقَتْ إِحْدَاهُمَا الأُخْرَى غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{930}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah (ﷺ) said: "If any one of you says: 'Amin' and the angels in Heaven say Amin, and the one coincides with the other, his previous sins will be forgiven}}
\hadithdefcmd{nasai}{931}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا رِفَاعَةُ بْنُ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ رِفَاعَةَ بْنِ رَافِعٍ، عَنْ عَمِّ، أَبِيهِ مُعَاذِ بْنِ رِفَاعَةَ بْنِ رَافِعٍ عَنْ أَبِيهِ، قَالَ صَلَّيْتُ خَلْفَ النَّبِيِّ صلى الله عليه وسلم فَعَطَسْتُ فَقُلْتُ الْحَمْدُ لِلَّهِ حَمْدًا كَثِيرًا طَيِّبًا مُبَارَكًا فِيهِ مُبَارَكًا عَلَيْهِ كَمَا يُحِبُّ رَبُّنَا وَيَرْضَى ‏.‏ فَلَمَّا صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم انْصَرَفَ فَقَالَ ‏"‏ مَنِ الْمُتَكَلِّمُ فِي الصَّلاَةِ ‏"‏ ‏.‏ فَلَمْ يُكَلِّمْهُ أَحَدٌ ثُمَّ قَالَهَا الثَّانِيَةَ ‏"‏ مَنِ الْمُتَكَلِّمُ فِي الصَّلاَةِ ‏"‏ ‏.‏ فَقَالَ رِفَاعَةُ بْنُ رَافِعِ بْنِ عَفْرَاءَ أَنَا يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ كَيْفَ قُلْتَ ‏"‏ ‏.‏ قَالَ قُلْتُ الْحَمْدُ لِلَّهِ حَمْدًا كَثِيرًا طَيِّبًا مُبَارَكًا فِيهِ مُبَارَكًا عَلَيْهِ كَمَا يُحِبُّ رَبُّنَا وَيَرْضَى ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لَقَدِ ابْتَدَرَهَا بِضْعَةٌ وَثَلاَثُونَ مَلَكًا أَيُّهُمْ يَصْعَدُ بِهَا ‏"‏ ‏.‏\hadithno{931}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Mu'adh bin Rifa'ah bin Rafi' that :His father said: "I prayed behind the Prophet (ﷺ) and I sneezed and said: 'Al-hamdu lillahi, hamdan kathiran tayiban mubarakan fih, mubarakan'alaihi, kama yuhibbu rabbuna wa yarda (Praise be to Allah, much good and blessed praise as our Lord loves and is pleased with.)' When he finished praying, the Messenger of Allah (ﷺ) said: 'Who is the one who spoke during the prayer?' But no one said anything. Then he said it a second time: 'Who is the one who spoke during the prayer?' So Rifa'ah bin Rafi bin Afrah said: 'It was me, O Messenger of Allah.' He said: 'I said: "Praise be to Allah, much good and blessed praise as our Lord loves and is pleased with.'" The Prophet (ﷺ) said: 'By the One in Whose hand is my soul, thirty-odd angels hastened to see which of them would take it up}}
\hadithdefcmd{nasai}{932}{أَخْبَرَنَا عَبْدُ الْحَمِيدِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا مَخْلَدٌ، قَالَ حَدَّثَنَا يُونُسُ بْنُ أَبِي إِسْحَاقَ، عَنْ أَبِيهِ، عَنْ عَبْدِ الْجَبَّارِ بْنِ وَائِلٍ، عَنْ أَبِيهِ، قَالَ صَلَّيْتُ خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا كَبَّرَ رَفَعَ يَدَيْهِ أَسْفَلَ مِنْ أُذُنَيْهِ فَلَمَّا قَرَأَ ‏\{‏ غَيْرِ الْمَغْضُوبِ عَلَيْهِمْ وَلاَ الضَّالِّينَ ‏\}‏ قَالَ ‏"‏ آمِينَ ‏"‏ ‏.‏ فَسَمِعْتُهُ وَأَنَا خَلْفَهُ ‏.‏ قَالَ فَسَمِعَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَجُلاً يَقُولُ الْحَمْدُ لِلَّهِ حَمْدًا كَثِيرًا طَيِّبًا مُبَارَكًا فِيهِ فَلَمَّا سَلَّمَ النَّبِيُّ صلى الله عليه وسلم مِنْ صَلاَتِهِ قَالَ ‏"‏ مَنْ صَاحِبُ الْكَلِمَةِ فِي الصَّلاَةِ ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ أَنَا يَا رَسُولَ اللَّهِ وَمَا أَرَدْتُ بِهَا بَأْسًا ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَقَدِ ابْتَدَرَهَا اثْنَا عَشَرَ مَلَكًا فَمَا نَهْنَهَهَا شَىْءٌ دُونَ الْعَرْشِ ‏"‏ ‏.‏\hadithno{932}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abdul-Jabbar bin Wa'il that :His father said: "I prayed behind the Messenger of Allah (ﷺ) and when he said the takbir, he raised his hands to the bottom of his ears. When he recited: Not (the way) of those who earned Your anger, nor of those who went astray), he said: 'Amin,' and I could hear him although I was behind him. The Messenger of Allah (ﷺ) heard a man saying: 'Al-hamdu lillahi, hamdan kathiran tayiban mubarakan fih, (Praise be to Allah, much good and blessed praise.)' When the Prophet (ﷺ) said the salam and finished his prayer, he said: 'Who spoke those words during the prayer?' The man said: 'I did, O Messenger of Allah, but I did not mean anything bad thereby.' The Prophet (ﷺ) said: "Twelve angels hastened (to take it) and nothing is stopping it going all the way to the Throne}}
\hadithdefcmd{nasai}{933}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ سَأَلَ الْحَارِثُ بْنُ هِشَامٍ رَسُولَ اللَّهِ صلى الله عليه وسلم كَيْفَ يَأْتِيكَ الْوَحْىُ قَالَ ‏ "‏ فِي مِثْلِ صَلْصَلَةِ الْجَرَسِ فَيَفْصِمُ عَنِّي وَقَدْ وَعَيْتُ وَهُوَ أَشَدُّهُ عَلَىَّ وَأَحْيَانًا يَأْتِينِي فِي مِثْلِ صُورَةِ الْفَتَى فَيَنْبِذُهُ إِلَىَّ ‏"‏ ‏.‏\hadithno{933}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Aishah said:"Al-Harith bin Hisham asked the Messenger of Allah (ﷺ): 'How does the Revelation come to you?' He said: 'Like the ringing of a bell, and when it departs I remember what he (the Angel) said, and this is the hardest on me. And sometimes he (the Angel) comes to me in the form of a man and gives it to me}}
\hadithdefcmd{nasai}{934}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ الْحَارِثَ بْنَ هِشَامٍ، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم كَيْفَ يَأْتِيكَ الْوَحْىُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَحْيَانًا يَأْتِينِي فِي مِثْلِ صَلْصَلَةِ الْجَرَسِ وَهُوَ أَشَدُّهُ عَلَىَّ فَيَفْصِمُ عَنِّي وَقَدْ وَعَيْتُ مَا قَالَ وَأَحْيَانًا يَتَمَثَّلُ لِيَ الْمَلَكُ رَجُلاً فَيُكَلِّمُنِي فَأَعِي مَا يَقُولُ ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ وَلَقَدْ رَأَيْتُهُ يَنْزِلُ عَلَيْهِ فِي الْيَوْمِ الشَّدِيدِ الْبَرْدِ فَيَفْصِمُ عَنْهُ وَإِنَّ جَبِينَهُ لَيَتَفَصَّدُ عَرَقًا ‏.‏\hadithno{934}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Aishah that:Al-Harith bin Hisham asked the Messenger of Allah (ﷺ): 'How does the Revelation come to you?' He said: 'Like the ringing of a bell, and this is the hardest on me. When it departs I remember what he said. And sometimes the Angel appears to me in the form of a man and speaks to me, and I remember what he said." Aishah said: "I saw him when the Revelation came to him on a very cold day, and his forhead was dripping with sweat}}
\hadithdefcmd{nasai}{935}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ مُوسَى بْنِ أَبِي عَائِشَةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، فِي قَوْلِهِ عَزَّ وَجَلَّ ‏\{‏ لاَ تُحَرِّكْ بِهِ لِسَانَكَ لِتَعْجَلَ بِهِ * إِنَّ عَلَيْنَا جَمْعَهُ وَقُرْآنَهُ ‏\}‏ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُعَالِجُ مِنَ التَّنْزِيلِ شِدَّةً وَكَانَ يُحَرِّكُ شَفَتَيْهِ قَالَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ لاَ تُحَرِّكْ بِهِ لِسَانَكَ لِتَعْجَلَ بِهِ * إِنَّ عَلَيْنَا جَمْعَهُ وَقُرْآنَهُ ‏\}‏ قَالَ جَمْعَهُ فِي صَدْرِكَ ثُمَّ تَقْرَأَهُ ‏\{‏ فَإِذَا قَرَأْنَاهُ فَاتَّبِعْ قُرْآنَهُ ‏\}‏ قَالَ فَاسْتَمِعْ لَهُ وَأَنْصِتْ فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَتَاهُ جِبْرِيلُ اسْتَمَعَ فَإِذَا انْطَلَقَ قَرَأَهُ كَمَا أَقْرَأَهُ ‏.‏\hadithno{935}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn Abbas said:Concerning the saying of Allah, the Mighty and Sublime: "Move not your tongue concerning to make haste therewith. It is for Us to collect it and to give you the ability to recite it- "The Prophet (ﷺ) used to suffer a great deal of hardship when the Revelation came to him, and he used to move his lips. Allah said: Move not your tongue concerning to make haste therewith. It is for Us to collect it and to give you the ability to recite it." He said: " (This means) He will gather it in your heart, then you will recite it," And when We have recited it to you, then follow the recitation. He said: "So listen to it and remain silent. So when Jibril came to him, the Messenger of Allah (ﷺ) listened, and when he left, he would recite it as he had taught him}}
\hadithdefcmd{nasai}{936}{أَخْبَرَنَا نَصْرُ بْنُ عَلِيٍّ، قَالَ أَنْبَأَنَا عَبْدُ الأَعْلَى، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنِ ابْنِ مَخْرَمَةَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، - رضى الله عنه - قَالَ سَمِعْتُ هِشَامَ بْنَ حَكِيمِ بْنِ حِزَامٍ، يَقْرَأُ سُورَةَ الْفُرْقَانِ فَقَرَأَ فِيهَا حُرُوفًا لَمْ يَكُنْ نَبِيُّ اللَّهِ صلى الله عليه وسلم أَقْرَأَنِيهَا قُلْتُ مَنْ أَقْرَأَكَ هَذِهِ السُّورَةَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قُلْتُ كَذَبْتَ مَا هَكَذَا أَقْرَأَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَخَذْتُ بِيَدِهِ أَقُودُهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّكَ أَقْرَأْتَنِي سُورَةَ الْفُرْقَانِ وَإِنِّي سَمِعْتُ هَذَا يَقْرَأُ فِيهَا حُرُوفًا لَمْ تَكُنْ أَقْرَأْتَنِيهَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْرَأْ يَا هِشَامُ ‏"‏ ‏.‏ فَقَرَأَ كَمَا كَانَ يَقْرَأُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَكَذَا أُنْزِلَتْ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ اقْرَأْ يَا عُمَرُ ‏"‏ ‏.‏ فَقَرَأْتُ فَقَالَ ‏"‏ هَكَذَا أُنْزِلَتْ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ الْقُرْآنَ أُنْزِلَ عَلَى سَبْعَةِ أَحْرُفٍ ‏"‏ ‏.‏\hadithno{936}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn Makhramah that:Umar bin Al-Khattab, may Allah be pleased with him, said: "I heard Hisham bin Hakim bin Hizam reciting: Surat Al-Furqan, in a way that the Prophet of Allah (ﷺ) had not taught me. I said: 'Who taught you this Surah?' He said: 'The Messenger of Allah (ﷺ).' I said: 'You are lying; the Messenger of Allah (ﷺ) did not teach you like that. 'I took him by the hand and brought him to the Messenger of Allah (ﷺ) and said: 'O Messenger of Allah, you taught me Surat Al-Furqan, but I heard this man reciting it in a way that you did not teach me.' The Messenger of Allah (ﷺ) said: 'Recite, O Hisham.' So he recited it as he had recited it (before). The Messenger of Allah (ﷺ) said: 'It was revealed like this.' Then he said: 'Recite, O Umar.' So I recited it, and he said: 'It was revealed like this.' Then the Messenger of Allah (ﷺ) said: 'The Quran was revealed to be recited in seven different modes}}
\hadithdefcmd{nasai}{937}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدٍ الْقَارِيِّ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، - رضى الله عنه - يَقُولُ سَمِعْتُ هِشَامَ بْنَ حَكِيمٍ، يَقْرَأُ سُورَةَ الْفُرْقَانِ عَلَى غَيْرِ مَا أَقْرَؤُهَا عَلَيْهِ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَقْرَأَنِيهَا فَكِدْتُ أَنْ أَعْجَلَ عَلَيْهِ ثُمَّ أَمْهَلْتُهُ حَتَّى انْصَرَفَ ثُمَّ لَبَّبْتُهُ بِرِدَائِهِ فَجِئْتُ بِهِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي سَمِعْتُ هَذَا يَقْرَأُ سُورَةَ الْفُرْقَانِ عَلَى غَيْرِ مَا أَقْرَأْتَنِيهَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْرَأْ ‏"‏ ‏.‏ فَقَرَأَ الْقِرَاءَةَ الَّتِي سَمِعْتُهُ يَقْرَأُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَكَذَا أُنْزِلَتْ ‏"‏ ‏.‏ ثُمَّ قَالَ لِي ‏"‏ اقْرَأْ ‏"‏ ‏.‏ فَقَرَأْتُ فَقَالَ ‏"‏ هَكَذَا أُنْزِلَتْ إِنَّ هَذَا الْقُرْآنَ أُنْزِلَ عَلَى سَبْعَةِ أَحْرُفٍ ‏\{‏ فَاقْرَءُوا مَا تَيَسَّرَ مِنْهُ ‏\}‏ ‏"‏ ‏.‏\hadithno{937}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that AbdurRahman bin Abdul-Qari said:"I heard Umar bin Al-Khattab, may Allah be pleased with him, say: 'I heard Hisham bin Hakim bin Hizam reciting Surat Al-Furqan, in a way that I had not been taught, and the Messenger of Allah (ﷺ) had taught me. I was about to interrupt him (in his prayer), but I left him alone until he had finished. Then I grabbed him by his garment and brought him to the Messenger of Allah (ﷺ) and said: 'O Messenger of Allah, I heard this man reciting Surat Al-Furqan in a way that you did not teach me.' The Messenger of Allah (ﷺ) said to him: 'Recite.' So he recited it in the way that I had heard him recite. Then the Messenger of Allah (ﷺ) said: 'It was revealed like this.' Then he said to me: 'Recite.' So I recited it and he said: 'It was revealed like this. This Quran has been revealed in seven different modes, so recite as much of the Quran as may be easy for you}}
\hadithdefcmd{nasai}{938}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ الْمِسْوَرَ بْنَ مَخْرَمَةَ، وَعَبْدَ الرَّحْمَنِ بْنَ عَبْدٍ الْقَارِيَّ، أَخْبَرَاهُ أَنَّهُمَا، سَمِعَا عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ سَمِعْتُ هِشَامَ بْنَ حَكِيمٍ، يَقْرَأُ سُورَةَ الْفُرْقَانِ فِي حَيَاةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَاسْتَمَعْتُ لِقِرَاءَتِهِ فَإِذَا هُوَ يَقْرَؤُهَا عَلَى حُرُوفٍ كَثِيرَةٍ لَمْ يُقْرِئْنِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَكِدْتُ أُسَاوِرُهُ فِي الصَّلاَةِ فَتَصَبَّرْتُ حَتَّى سَلَّمَ فَلَمَّا سَلَّمَ لَبَّبْتُهُ بِرِدَائِهِ فَقُلْتُ مَنْ أَقْرَأَكَ هَذِهِ السُّورَةَ الَّتِي سَمِعْتُكَ تَقْرَؤُهَا فَقَالَ أَقْرَأَنِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقُلْتُ كَذَبْتَ ‏.‏ فَوَاللَّهِ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم هُوَ أَقْرَأَنِي هَذِهِ السُّورَةَ الَّتِي سَمِعْتُكَ تَقْرَؤُهَا فَانْطَلَقْتُ بِهِ أَقُودُهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي سَمِعْتُ هَذَا يَقْرَأُ سُورَةَ الْفُرْقَانِ عَلَى حُرُوفٍ لَمْ تُقْرِئْنِيهَا وَأَنْتَ أَقْرَأْتَنِي سُورَةَ الْفُرْقَانِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَرْسِلْهُ يَا عُمَرُ اقْرَأْ يَا هِشَامُ ‏"‏ ‏.‏ فَقَرَأَ عَلَيْهِ الْقِرَاءَةَ الَّتِي سَمِعْتُهُ يَقْرَؤُهَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَكَذَا أُنْزِلَتْ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْرَأْ يَا عُمَرُ ‏"‏ ‏.‏ فَقَرَأْتُ الْقِرَاءَةَ الَّتِي أَقْرَأَنِي قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَكَذَا أُنْزِلَتْ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ هَذَا الْقُرْآنَ أُنْزِلَ عَلَى سَبْعَةِ أَحْرُفٍ ‏\{‏ فَاقْرَءُوا مَا تَيَسَّرَ مِنْهُ ‏\}‏ ‏"‏ ‏.‏\hadithno{938}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Urwah bin Az-Zubair narrated that Al-Miswar bin Makhramah and AbdurRahman bin Abdul-Qari told him that:They heard Umar bin Al-Khattab say: "I heard Hisham bin Hakim bin Hizam reciting Surat Al-Furqan during the lifetime of the Messenger of Allah (ﷺ), so I listened to his recitation and he was reciting it in a way that the Messenger of Allah (ﷺ) had not taught me. I was about to jump on him while he was praying, but I waited patiently until he said the Salam (at the end of the prayer). When he had said the Salam I grabbed him by his garment and said: 'Who taught you this Surah that I heard you reciting?' He said: 'The Messenger of Allah (ﷺ) taught me it. I said: 'You are lying, by Allah! The Messenger of Allah (ﷺ) is the one who taught me this Surah that I heard you reciting.' I took him to the Messenger of Allah (ﷺ) and said: 'O Messenger of Allah, I heard this man reciting Surat Al-Furqan in a way that you did not teach me, but you taught me Surat Al-Furqan.' The Messenger of Allah (ﷺ) said:' Let him go, O Umar. Recite, O Hisham.' So I recited it to him in the way that I had heard him recite. The Messenger of Allah (ﷺ) said: 'It was revealed like this.' Then the Messenger of Allah (ﷺ) said: 'Recite, O Umar.' So I recited it in the way that he had taught me. The Messenger of Allah (ﷺ) said: 'It was revealed like this.' Then the Messenger of Allah (ﷺ) said: 'This Quran has been revealed to be recited in seven different modes, so recite as much of the Quran as may be easy for you}}
\hadithdefcmd{nasai}{939}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، غُنْدَرٌ قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ أُبَىِّ بْنِ كَعْبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ عِنْدَ أَضَاةِ بَنِي غِفَارٍ فَأَتَاهُ جِبْرِيلُ عَلَيْهِ السَّلاَمُ فَقَالَ إِنَّ اللَّهَ عَزَّ وَجَلَّ يَأْمُرُكَ أَنْ تُقْرِئَ أُمَّتَكَ الْقُرْآنَ عَلَى حَرْفٍ ‏.‏ قَالَ ‏"‏ أَسْأَلُ اللَّهَ مُعَافَاتَهُ وَمَغْفِرَتَهُ وَإِنَّ أُمَّتِي لاَ تُطِيقُ ذَلِكَ ‏"‏ ‏.‏ ثُمَّ أَتَاهُ الثَّانِيَةَ فَقَالَ إِنَّ اللَّهَ عَزَّ وَجَلَّ يَأْمُرُكَ أَنْ تُقْرِئَ أُمَّتَكَ الْقُرْآنَ عَلَى حَرْفَيْنِ قَالَ ‏"‏ أَسْأَلُ اللَّهَ مُعَافَاتَهُ وَمَغْفِرَتَهُ وَإِنَّ أُمَّتِي لاَ تُطِيقُ ذَلِكَ ‏"‏ ‏.‏ ثُمَّ جَاءَهُ الثَّالِثَةَ فَقَالَ إِنَّ اللَّهَ عَزَّ وَجَلَّ يَأْمُرُكَ أَنْ تُقْرِئَ أُمَّتَكَ الْقُرْآنَ عَلَى ثَلاَثَةِ أَحْرُفٍ ‏.‏ قَالَ ‏"‏ أَسْأَلُ اللَّهَ مُعَافَاتَهُ وَمَغْفِرَتَهُ وَإِنَّ أُمَّتِي لاَ تُطِيقُ ذَلِكَ ‏"‏ ‏.‏ ثُمَّ جَاءَهُ الرَّابِعَةَ فَقَالَ إِنَّ اللَّهَ عَزَّ وَجَلَّ يَأْمُرُكَ أَنْ تُقْرِئَ أُمَّتَكَ الْقُرْآنَ عَلَى سَبْعَةِ أَحْرُفٍ فَأَيُّمَا حَرْفٍ قَرَءُوا عَلَيْهِ فَقَدْ أَصَابُوا ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا الْحَدِيثُ خُولِفَ فِيهِ الْحَكَمُ خَالَفَهُ مَنْصُورُ بْنُ الْمُعْتَمِرِ رَوَاهُ عَنْ مُجَاهِدٍ عَنْ عُبَيْدِ بْنِ عُمَيْرٍ مُرْسَلاً ‏.‏\hadithno{939}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ubayy bin Ka'b that:The Messenger of Allah (ﷺ) was by a pond belonging to Banu Ghifar when Jibril, peace be upon him, came to him and said: "Allah commands you to teach your Ummah the Quran with one way of recitation." He said: "I ask my Lord for protection and forgiveness, my Ummah cannot bear that." Then he came to him a second time and said: "Allah commands you to teach your Ummah the Quran with two ways of recitation." He said: ""I ask my Lord for protection and forgiveness, my Ummah cannot bear that." Then he came to him a third time and said: "Allah commands you to teach your Ummah the Quran with three ways of recitation." He said: "I ask my Lord for protection and forgiveness, my Ummah cannot bear that." Then he came to him a fourth time and said: "Allah commands you to teach your Ummah the Quran with seven ways of recitation, and whichever the way they recite it will be correct}}
\hadithdefcmd{nasai}{940}{أَخْبَرَنِي عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا أَبُو جَعْفَرِ بْنُ نُفَيْلٍ، قَالَ قَرَأْتُ عَلَى مَعْقِلِ بْنِ عُبَيْدِ اللَّهِ عَنْ عِكْرِمَةَ بْنِ خَالِدٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ أَقْرَأَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم سُورَةً فَبَيْنَا أَنَا فِي الْمَسْجِدِ جَالِسٌ إِذْ سَمِعْتُ رَجُلاً يَقْرَؤُهَا يُخَالِفُ قِرَاءَتِي فَقُلْتُ لَهُ مَنْ عَلَّمَكَ هَذِهِ السُّورَةَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقُلْتُ لاَ تُفَارِقْنِي حَتَّى نَأْتِيَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَتَيْتُهُ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ هَذَا خَالَفَ قِرَاءَتِي فِي السُّورَةِ الَّتِي عَلَّمْتَنِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْرَأْ يَا أُبَىُّ ‏"‏ ‏.‏ فَقَرَأْتُهَا فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَحْسَنْتَ ‏"‏ ‏.‏ ثُمَّ قَالَ لِلرَّجُلِ ‏"‏ اقْرَأْ ‏"‏ ‏.‏ فَقَرَأَ فَخَالَفَ قِرَاءَتِي فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَحْسَنْتَ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا أُبَىُّ إِنَّهُ أُنْزِلَ الْقُرْآنُ عَلَى سَبْعَةِ أَحْرُفٍ كُلُّهُنَّ شَافٍ كَافٍ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ مَعْقِلُ بْنُ عُبَيْدِ اللَّهِ لَيْسَ بِذَلِكَ الْقَوِيِّ ‏.‏\hadithno{940}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ubayy bin Ka'b said:"The Messenger of Allah (ﷺ) taught me a surah, and when I was sitting in the masjid I heard a man reciting it in a way that was different from mine. I said to him: 'Who taught you this surah?' He said: 'The Messenger of Allah (ﷺ).' I said: 'Stay with me until we go to the Messenger of Allah (ﷺ).' So we came to him and I said: 'O Messenger of Allah, this man recites a surah that you taught me differently.' The Messenger of Allah (ﷺ) said: 'Recite, O Ubayy.' So I recited it, and the Messenger of Allah (ﷺ) said to me: 'You have done well.' Then he said to the man: 'Recite.' So he recited it and it was different to my recitation. The Messenger of Allah (ﷺ) said to him: 'You have done well.' Then the Messenger of Allah (ﷺ) said: 'O Ubayy, the Quran has been revealed with seven different modes of reciation, all of which are good and sound}}
\hadithdefcmd{nasai}{941}{أَخْبَرَنِي يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، عَنْ أُبَىٍّ، قَالَ مَا حَاكَ فِي صَدْرِي مُنْذُ أَسْلَمْتُ إِلاَّ أَنِّي قَرَأْتُ آيَةً وَقَرَأَهَا آخَرُ غَيْرَ قِرَاءَتِي فَقُلْتُ أَقْرَأَنِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ وَقَالَ الآخَرُ أَقْرَأَنِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ يَا نَبِيَّ اللَّهِ أَقْرَأْتَنِي آيَةَ كَذَا وَكَذَا قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ وَقَالَ الآخَرُ أَلَمْ تُقْرِئْنِي آيَةَ كَذَا وَكَذَا قَالَ ‏"‏ نَعَمْ إِنَّ جِبْرِيلَ وَمِيكَائِيلَ عَلَيْهِمَا السَّلاَمُ أَتَيَانِي فَقَعَدَ جِبْرِيلُ عَنْ يَمِينِي وَمِيكَائِيلُ عَنْ يَسَارِي فَقَالَ جِبْرِيلُ عَلَيْهِ السَّلاَمُ اقْرَإِ الْقُرْآنَ عَلَى حَرْفٍ ‏.‏ قَالَ مِيكَائِيلُ اسْتَزِدْهُ اسْتَزِدْهُ حَتَّى بَلَغَ سَبْعَةَ أَحْرُفٍ فَكُلُّ حَرْفٍ شَافٍ كَافٍ ‏"‏ ‏.‏\hadithno{941}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ubayy said:"I had no confusion in my mind from that time I embraced Islam, except when I recited a verse and another man recited it differently. I said: 'The Messenger of Allah (ﷺ) taught me this.' And the other man said: 'The Messenger of Allah (ﷺ) taught me too.' So I went to the Prophet (ﷺ) and said: 'O Prophet of Allah, did you not teach me such and such a verse?' He said: 'Yes.' The other man said: 'Did you not teach me such and such a verse?' He said: 'Yes. Jibril and Mika'il, peace be upon them, came to me, and Jibril sat on my right and Mika'il on my left. Jibril, peace be upon him, said: "Recite the Quran with one way of recitation.' Mika'il said: 'Teach him more, teach him more- until there were seven modes of recitation, each of which is good and sound}}
\hadithdefcmd{nasai}{942}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَثَلُ صَاحِبِ الْقُرْآنِ كَمَثَلِ صَاحِبِ الإِبِلِ الْمُعَقَّلَةِ إِذَا عَاهَدَ عَلَيْهَا أَمْسَكَهَا وَإِنْ أَطْلَقَهَا ذَهَبَتْ ‏"‏ ‏.‏\hadithno{942}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn Umar that:The Messenger of Allah (ﷺ) said: "The one who learns the Quran is like the owner of a hobbled camel. If he pays attention to it, he will keep it, but if he releases it, it will go away}}
\hadithdefcmd{nasai}{943}{أَخْبَرَنَا عِمْرَانُ بْنُ مُوسَى، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ بِئْسَمَا لأَحَدِهِمْ أَنْ يَقُولَ نَسِيتُ آيَةَ كَيْتَ وَكَيْتَ بَلْ هُوَ نُسِّيَ اسْتَذْكِرُوا الْقُرْآنَ فَإِنَّهُ أَسْرَعُ تَفَصِّيًا مِنْ صُدُورِ الرِّجَالِ مِنَ النَّعَمِ مِنْ عُقُلِهِ ‏"‏.‏\hadithno{943}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abdullah that:The Prophet (ﷺ) said: "It is not right for any one of you to say: 'I have forgotten such and such a verse.' Rather, he has been caused to forget. Study the Qur'an, for it escapes from the heart of man faster than a camel escapes from its fetter}}
\hadithdefcmd{nasai}{944}{أَخْبَرَنِي عِمْرَانُ بْنُ يَزِيدَ، قَالَ حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ الْفَزَارِيُّ، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ حَكِيمٍ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ يَسَارٍ، أَنَّ ابْنَ عَبَّاسٍ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقْرَأُ فِي رَكْعَتَىِ الْفَجْرِ فِي الأُولَى مِنْهُمَا الآيَةَ الَّتِي فِي الْبَقَرَةِ ‏\{‏ قُولُوا آمَنَّا بِاللَّهِ وَمَا أُنْزِلَ إِلَيْنَا ‏\}‏ إِلَى آخِرِ الآيَةِ وَفِي الأُخْرَى ‏\{‏ آمَنَّا بِاللَّهِ وَاشْهَدْ بِأَنَّا مُسْلِمُونَ ‏\}.‏\hadithno{944}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ibn Abbad narrated that:The Messenger of Allah (ﷺ) used to recite in teh first rak'ah of Fajr "Say: We believe in Allah and that which has been sent down to us" to the end verse, and in the second rak'ah, "We believe in Allah, and bear witness that we are Muslims}}
\hadithdefcmd{nasai}{945}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، دُحَيْمٌ قَالَ حَدَّثَنَا مَرْوَانُ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ كَيْسَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَرَأَ فِي رَكْعَتَىِ الْفَجْرِ ‏\{‏ قُلْ يَا أَيُّهَا الْكَافِرُونَ ‏\}‏ وَ ‏\{‏ قُلْ هُوَ اللَّهُ أَحَدٌ ‏\}‏\hadithno{945}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah (ﷺ) recited: "Say: O you disbelievers" and "Say: He is Allah, (the) One" in the two rak'ahs of Fajr}}
\hadithdefcmd{nasai}{946}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ إِنْ كُنْتُ لأَرَى رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي رَكْعَتَىِ الْفَجْرِ فَيُخَفِّفُهُمَا حَتَّى أَقُولَ أَقَرَأَ فِيهِمَا بِأُمِّ الْكِتَابِ\hadithno{946}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Aishah said:"I would see the Messenger of Allah (ﷺ) praying two rak'ahs of Fajr and making them so brief that I said: 'Did he recite the Umm Al-Kitab in them?}}
\hadithdefcmd{nasai}{947}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ شَبِيبٍ أَبِي رَوْحٍ، عَنْ رَجُلٍ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ صَلَّى صَلاَةَ الصُّبْحِ فَقَرَأَ الرُّومَ فَالْتَبَسَ عَلَيْهِ فَلَمَّا صَلَّى قَالَ ‏ "‏ مَا بَالُ أَقْوَامٍ يُصَلُّونَ مَعَنَا لاَ يُحْسِنُونَ الطُّهُورَ فَإِنَّمَا يَلْبِسُ عَلَيْنَا الْقُرْآنَ أُولَئِكَ ‏"‏ ‏.‏\hadithno{947}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Shabib Abi Rawh, from a man among the companions of the Prophet (ﷺ), that:He prayed Subh and recited Ar-Rum, but he stumbled in his recitation. When he had finished praying he said: 'What is the matter with people who pray with us without purifying themselves properly? Those people make us stumble in reciting Quran}}
\hadithdefcmd{nasai}{948}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَزِيدُ، قَالَ أَنْبَأَنَا سُلَيْمَانُ التَّيْمِيُّ، عَنْ سَيَّارٍ، - يَعْنِي ابْنَ سَلاَمَةَ - عَنْ أَبِي بَرْزَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقْرَأُ فِي صَلاَةِ الْغَدَاةِ بِالسِّتِّينَ إِلَى الْمِائَةِ ‏.‏\hadithno{948}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Barzah that:The Messenger of Allah (ﷺ) used to recite between sixty and one hundred verses in Al-Ghadah (Subh) prayer}}
\hadithdefcmd{nasai}{949}{أَخْبَرَنَا عِمْرَانُ بْنُ يَزِيدَ، قَالَ حَدَّثَنَا ابْنُ أَبِي الرِّجَالِ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ أُمِّ هِشَامٍ بِنْتِ حَارِثَةَ بْنِ النُّعْمَانِ، قَالَتْ مَا أَخَذْتُ ‏\{‏ ق وَالْقُرْآنِ الْمَجِيدِ ‏\}‏ إِلاَّ مِنْ وَرَاءِ رَسُولِ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي بِهَا فِي الصُّبْحِ ‏.‏\hadithno{949}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Umm Hisham bint Harithah bin An-Nu'man said:"I only learned :Qaf. By the Glorious Quran.' Behind the Messenger of Allah (ﷺ); he used to recite it in Subh}}
\hadithdefcmd{nasai}{950}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، وَمُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، - وَاللَّفْظُ لَهُ - قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، قَالَ سَمِعْتُ عَمِّي، يَقُولُ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم الصُّبْحَ فَقَرَأَ فِي إِحْدَى الرَّكْعَتَيْنِ ‏\{‏ وَالنَّخْلَ بَاسِقَاتٍ لَهَا طَلْعٌ نَضِيدٌ ‏\}‏ قَالَ شُعْبَةُ فَلَقِيتُهُ فِي السُّوقِ فِي الزِّحَامِ فَقَالَ ‏\{‏ ق ‏\}‏ ‏.‏\hadithno{950}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ziyad bin Ilaqah said:"I heard my paternal uncle say: 'I prayed Subh with the Messenger of Allah (ﷺ), and in one of the rak'ahs he recited: "And tall date palms, with ranged clusters}}
\hadithdefcmd{nasai}{951}{أَخْبَرَنَا مُحَمَّدُ بْنُ أَبَانَ الْبَلْخِيُّ، قَالَ حَدَّثَنَا وَكِيعُ بْنُ الْجَرَّاحِ، عَنْ مِسْعَرٍ، وَالْمَسْعُودِيِّ، عَنِ الْوَلِيدِ بْنِ سُرَيْعٍ، عَنْ عَمْرِو بْنِ حُرَيْثٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقْرَأُ فِي الْفَجْرِ ‏\{‏ إِذَا الشَّمْسُ كُوِّرَتْ ‏\}‏ ‏.‏\hadithno{951}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Amr bin Huraith said:"I heard the Prophet (ﷺ) reciting: 'When the sun is wound round.' in fajr}}
\hadithdefcmd{nasai}{952}{أَخْبَرَنَا مُوسَى بْنُ حِزَامٍ التِّرْمِذِيُّ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ، - وَاللَّفْظُ لَهُ - قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ أَخْبَرَنِي سُفْيَانُ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِيهِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَنَّهُ سَأَلَ النَّبِيَّ صلى الله عليه وسلم عَنِ الْمُعَوِّذَتَيْنِ قَالَ عُقْبَةُ فَأَمَّنَا بِهِمَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي صَلاَةِ الْفَجْرِ ‏.‏\hadithno{952}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Uqbah bin Amr that:He asked the Prophet (ﷺ) about Al-Mua'awwidhatain. Uqbah said: "The Messenger of Allah (ﷺ) led us in praying Fajr and recited them}}
\hadithdefcmd{nasai}{953}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي عِمْرَانَ، أَسْلَمَ عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ اتَّبَعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ رَاكِبٌ فَوَضَعْتُ يَدِي عَلَى قَدَمِهِ فَقُلْتُ أَقْرِئْنِي يَا رَسُولَ اللَّهِ سُورَةَ هُودٍ وَسُورَةَ يُوسُفَ ‏.‏ فَقَالَ ‏"‏ لَنْ تَقْرَأَ شَيْئًا أَبْلَغَ عِنْدَ اللَّهِ مِنْ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ الْفَلَقِ ‏\}‏ وَ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ النَّاسِ ‏\}‏ ‏"‏ ‏.‏\hadithno{953}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Uqbah bin Amr said:"I followed the Messenger of Allah (ﷺ) when he was riding, and I placed my hand on his foot and said : O Messenger of Allah, teach me Surah Hud and Surah Yusuf. He said: 'You will never recite anything greater before Allah than: "Say: I seek refuge with (Allah), the Lord of the daybreak." And "Say: I seek refuge with (Allah) the Lord of mankind}}
\hadithdefcmd{nasai}{954}{أَخْبَرَنِي مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ بَيَانٍ، عَنْ قَيْسٍ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ آيَاتٌ أُنْزِلَتْ عَلَىَّ اللَّيْلَةَ لَمْ يُرَ مِثْلُهُنَّ قَطُّ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ الْفَلَقِ ‏\}‏ وَ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ النَّاسِ ‏\}‏ ‏"‏ ‏.‏\hadithno{954}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Uqbah bin Amr said:The Messenger of Allah (ﷺ) said: 'Some verses were revealed to me tonight, the likes of which have never been seen: "Say: I seek refuge with (Allah), the Lord of the daybreak." [Surat al-Falaq:1] and "Say: I seek refuge with (Allah) the Lord of mankind." [Surat an-Naas:]}}
\hadithdefcmd{nasai}{955}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، ح وَأَنْبَأَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، - وَاللَّفْظُ لَهُ - عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقْرَأُ فِي صَلاَةِ الصُّبْحِ يَوْمَ الْجُمُعَةِ ‏\{‏ الم * تَنْزِيلُ ‏\}‏ وَ ‏\{‏ هَلْ أَتَى ‏\}‏\hadithno{955}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah (ﷺ) used to recite: "Alif-Lam-Mim. The revelation of the Book" and: "Has there not been over man" in Subh prayer on Friday}}
\hadithdefcmd{nasai}{956}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، ح وَأَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا شَرِيكٌ، - وَاللَّفْظُ لَهُ - عَنِ الْمُخَوَّلِ بْنِ رَاشِدٍ، عَنْ مُسْلِمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْرَأُ فِي صَلاَةِ الصُّبْحِ يَوْمَ الْجُمُعَةِ ‏\{‏ تَنْزِيلُ ‏\}‏ السَّجْدَةَ وَ ‏\{‏ هَلْ أَتَى عَلَى الإِنْسَانِ ‏\}‏ ‏.‏\hadithno{956}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn Abbas that:The Prophet (ﷺ) used to recite: The revelation of the Book and; 'Has there not been over man.' in Subh prayer on Friday}}
\hadithdefcmd{nasai}{957}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ الْحَسَنِ الْمِقْسَمِيُّ، قَالَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، عَنْ عُمَرَ بْنِ ذَرٍّ، عَنْ أَبِيهِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سَجَدَ فِي ‏\{‏ ص ‏\}‏ وَقَالَ ‏ "‏ سَجَدَهَا دَاوُدُ تَوْبَةً وَنَسْجُدُهَا شُكْرًا ‏"‏ ‏.‏\hadithno{957}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn Abbas that:The Prophet (ﷺ) prostrated in Sad and said: "Dawud did this prostration in repentance and we do it in thanksgiving}}
\hadithdefcmd{nasai}{958}{أَخْبَرَنَا عَبْدُ الْمَلِكِ بْنُ عَبْدِ الْحَمِيدِ بْنِ مَيْمُونِ بْنِ مِهْرَانَ، قَالَ حَدَّثَنَا ابْنُ حَنْبَلٍ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا رَبَاحٌ، عَنْ مَعْمَرٍ، عَنِ ابْنِ طَاوُسٍ، عَنْ عِكْرِمَةَ بْنِ خَالِدٍ، عَنْ جَعْفَرِ بْنِ الْمُطَّلِبِ بْنِ أَبِي وَدَاعَةَ، عَنْ أَبِيهِ، قَالَ قَرَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَكَّةَ سُورَةَ النَّجْمِ فَسَجَدَ وَسَجَدَ مَنْ عِنْدَهُ فَرَفَعْتُ رَأْسِي وَأَبَيْتُ أَنْ أَسْجُدَ وَلَمْ يَكُنْ يَوْمَئِذٍ أَسْلَمَ الْمُطَّلِبُ ‏.‏\hadithno{958}\hadithgrade{Abu Ghuddah: Hasan Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ja'far bin Al-Muttalib bin Abi Wada'ah that:His father said: "The Messenger of Allah (ﷺ) recited Surat An-Najm in Makkah and prostrated, and those who were with him prostrated. I raised my head and refused to prostrate." At that time Al-Muttalib had not yet accepted Islam}}
\hadithdefcmd{nasai}{959}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَرَأَ النَّجْمَ فَسَجَدَ فِيهَا ‏.‏\hadithno{959}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abdullah that:The Messenger of Allah (ﷺ) recited An-Najm and prostrated during it}}
\hadithdefcmd{nasai}{960}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنْ يَزِيدَ بْنِ خُصَيْفَةَ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ قُسَيْطٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّهُ أَخْبَرَهُ أَنَّهُ، سَأَلَ زَيْدَ بْنَ ثَابِتٍ عَنِ الْقِرَاءَةِ، مَعَ الإِمَامِ فَقَالَ لاَ قِرَاءَةَ مَعَ الإِمَامِ فِي شَىْءٍ وَزَعَمَ أَنَّهُ قَرَأَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏\{‏ وَالنَّجْمِ إِذَا هَوَى ‏\}‏ فَلَمْ يَسْجُدْ ‏.‏\hadithno{960}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ata' bin Yasar that:He asked Zaid bin Thabit about reciting with the Imam. He said: "There is no recitation with the Imam in anything." And he claimed that he had recited: "By the star when it goes down (or vanishes)" to the Messenger of Allah (ﷺ) and he did not prostrate}}
\hadithdefcmd{nasai}{961}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، قَرَأَ بِهِمْ ‏\{‏ إِذَا السَّمَاءُ انْشَقَّتْ ‏\}‏ فَسَجَدَ فِيهَا فَلَمَّا انْصَرَفَ أَخْبَرَهُمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سَجَدَ فِيهَا ‏.‏\hadithno{961}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Salamah bin Abdur- Rahman that:Abu Hurairah (led them in prayer and) recited: "When the heaven is split asunder." and prostrated during it. When he had finished praying, he told them that the Messenger of Allah (ﷺ) had prostrated during it}}
\hadithdefcmd{nasai}{962}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، قَالَ أَنْبَأَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ عَيَّاشٍ، عَنِ ابْنِ قَيْسٍ، - وَهُوَ مُحَمَّدٌ - عَنْ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَجَدَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي ‏\{‏ إِذَا السَّمَاءُ انْشَقَّتْ ‏\}‏ ‏.‏\hadithno{962}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) prostrated during: 'When the heaven is split asunder}}
\hadithdefcmd{nasai}{963}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَجَدْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي ‏\{‏ إِذَا السَّمَاءُ انْشَقَّتْ ‏\}‏ وَ ‏\{‏ اقْرَأْ بِاسْمِ رَبِّكَ ‏\}‏\hadithno{963}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"We prostrated with the Messenger of Allah (ﷺ) during: When the heaven is split asunder and Read! In the Name of your Lord}}
\hadithdefcmd{nasai}{964}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي بَكْرِ بْنِ مُحَمَّدٍ، عَنْ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، عَنْ أَبِي هُرَيْرَةَ، مِثْلَهُ ‏.‏\hadithno{964}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Narrated from Abu Hurairah:(Another chain) from Abu Hurairah, with similar}}
\hadithdefcmd{nasai}{965}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا قُرَّةُ بْنُ خَالِدٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَجَدَ أَبُو بَكْرٍ وَعُمَرُ - رضى الله عنهما - فِي ‏\{‏ إِذَا السَّمَاءُ انْشَقَّتْ ‏\}‏ وَمَنْ هُوَ خَيْرٌ مِنْهُمَا ‏.‏\hadithno{965}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"Abu Bakr and Umar prostrated during: 'When the heaven is split asunder,' as did the one who was better than them (the Prophet (ﷺ)}}
\hadithdefcmd{nasai}{966}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا الْمُعْتَمِرُ، عَنْ قُرَّةَ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَجَدَ أَبُو بَكْرٍ وَعُمَرُ - رضى الله عنهما - وَمَنْ هُوَ خَيْرٌ مِنْهُمَا صلى الله عليه وسلم فِي ‏\{‏ إِذَا السَّمَاءُ انْشَقَّتْ ‏\}‏ وَ ‏\{‏ اقْرَأْ بِاسْمِ رَبِّكَ ‏\}‏ ‏.‏\hadithno{966}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"Abu Bakr and Umar, may Allah be pleased with them both, and the one who was better than them prostrated during 'When the heaven is split asunder' and 'Read! In the name of your Lord}}
\hadithdefcmd{nasai}{967}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ عَطَاءِ بْنِ مِينَاءَ، عَنْ أَبِي هُرَيْرَةَ، وَوَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ عَطَاءِ بْنِ مِينَاءَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَجَدْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي ‏\{‏ إِذَا السَّمَاءُ انْشَقَّتْ ‏\}‏ وَ ‏\{‏ اقْرَأْ بِاسْمِ رَبِّكَ ‏\}‏\hadithno{967}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"I prostrated with the Messenger of Allah (ﷺ) during; 'When the heaven is split asunder' and 'Read! In the Name of your Lord}}
\hadithdefcmd{nasai}{968}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ سُلَيْمٍ، - وَهُوَ ابْنُ أَخْضَرَ - عَنِ التَّيْمِيِّ، قَالَ حَدَّثَنِي بَكْرُ بْنُ عَبْدِ اللَّهِ الْمُزَنِيُّ، عَنْ أَبِي رَافِعٍ، قَالَ صَلَّيْتُ خَلْفَ أَبِي هُرَيْرَةَ صَلاَةَ الْعِشَاءِ - يَعْنِي الْعَتَمَةَ - فَقَرَأَ سُورَةَ ‏\{‏ إِذَا السَّمَاءُ انْشَقَّتْ ‏\}‏ فَسَجَدَ فِيهَا فَلَمَّا فَرَغَ قُلْتُ يَا أَبَا هُرَيْرَةَ هَذِهِ - يَعْنِي سَجْدَةً - مَا كُنَّا نَسْجُدُهَا ‏.‏ قَالَ سَجَدَ بِهَا أَبُو الْقَاسِمِ صلى الله عليه وسلم وَأَنَا خَلْفَهُ فَلاَ أَزَالُ أَسْجُدُ بِهَا حَتَّى أَلْقَى أَبَا الْقَاسِمِ صلى الله عليه وسلم ‏.‏\hadithno{968}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Rafi' said:"I prayed Isha' prayer- meaning Al-'Atamah behind Abu Hurairah and he recited: 'When the heaven is split asunder' and prostrated during it. When he had finished praying, I said: 'O Abu Hurairah, (this is) a prostration that we are not used to.' He said: 'Abu Al-Qasim (ﷺ) did this prostration and I was (praying) behind him, and I will continue to do this prostration until I meet Abu Al-Qasim}}
\hadithdefcmd{nasai}{969}{أَخْبَرَنَا مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ رَقَبَةَ، عَنْ عَطَاءٍ، قَالَ قَالَ أَبُو هُرَيْرَةَ كُلُّ صَلاَةٍ يُقْرَأُ فِيهَا فَمَا أَسْمَعَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَسْمَعْنَاكُمْ وَمَا أَخْفَاهَا أَخْفَيْنَا مِنْكُمْ ‏.‏\hadithno{969}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Ata said:"Abu Hurairah said: "In should be recitation in every prayer. What the Messenger of Allah (ﷺ) made us hear (by reciting out loud) we make you hear, and what he hid from us (by reciting silently) we hide from you}}
\hadithdefcmd{nasai}{970}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ أَنْبَأَنَا خَالِدٌ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ فِي كُلِّ صَلاَةٍ قِرَاءَةٌ فَمَا أَسْمَعَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَسْمَعْنَاكُمْ وَمَا أَخْفَاهَا أَخْفَيْنَا مِنْكُمْ ‏.‏\hadithno{970}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"In every prayer there is recitation. What the Messenger of Allah (ﷺ) made us hear (by reciting out loud) we make you hear, and what he hid from us (by reciting silently) we hide from you}}
\hadithdefcmd{nasai}{971}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِبْرَاهِيمَ بْنِ صُدْرَانَ، قَالَ حَدَّثَنَا سَلْمُ بْنُ قُتَيْبَةَ، قَالَ حَدَّثَنَا هَاشِمُ بْنُ الْبَرِيدِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ كُنَّا نُصَلِّي خَلْفَ النَّبِيِّ صلى الله عليه وسلم الظُّهْرَ فَنَسْمَعُ مِنْهُ الآيَةَ بَعْدَ الآيَاتِ مِنْ سُورَةِ لُقْمَانَ وَالذَّارِيَاتِ ‏.‏\hadithno{971}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Al-Bara' said:"We used to pray Zuhr behind the Prophet (ﷺ) and we heard some of the verses from Surah Luqman and Adh-Dhariyat from him}}
\hadithdefcmd{nasai}{972}{أَخْبَرَنَا مُحَمَّدُ بْنُ شُجَاعٍ الْمَرُّوذِيُّ، قَالَ حَدَّثَنَا أَبُو عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدٍ، قَالَ سَمِعْتُ أَبَا بَكْرِ بْنَ النَّضْرِ، قَالَ كُنَّا بِالطَّفِّ عِنْدَ أَنَسٍ فَصَلَّى بِهِمُ الظُّهْرَ فَلَمَّا فَرَغَ قَالَ إِنِّي صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم صَلاَةَ الظُّهْرِ فَقَرَأَ لَنَا بِهَاتَيْنِ السُّورَتَيْنِ فِي الرَّكْعَتَيْنِ بِـ ‏\{‏ سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى ‏\}‏ وَ ‏\{‏ هَلْ أَتَاكَ حَدِيثُ الْغَاشِيَةِ ‏\}‏ ‏.‏\hadithno{972}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Abu Bakr bin An-Nadr said:"We were in At-Taff with Anas, and he led them in praying Zuhr. When he had finished, he said: 'I prayed Zuhr with the Messenger of Allah (ﷺ) and he recited two surahs for us in the two rak'ahs: "Glorify the Name of your Lord, the Most High' and 'Has there come to you the narration of the over-whelming (i.e. The Day of Resurrection)?}}
\hadithdefcmd{nasai}{973}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا الْوَلِيدُ، عَنْ سَعِيدِ بْنِ عَبْدِ الْعَزِيزِ، عَنْ عَطِيَّةَ بْنِ قَيْسٍ، عَنْ قَزَعَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ لَقَدْ كَانَتْ صَلاَةُ الظُّهْرِ تُقَامُ فَيَذْهَبُ الذَّاهِبُ إِلَى الْبَقِيعِ فَيَقْضِي حَاجَتَهُ ثُمَّ يَتَوَضَّأُ ثُمَّ يَجِئُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم فِي الرَّكْعَةِ الأُولَى يُطَوِّلُهَا ‏.‏\hadithno{973}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"The Iqamah for Zuhr prayer would be said, and a person could go to the Al-Baqi', relieve himself, perform wudhu, and come (to the masjid), and the Messenger of Allah (ﷺ) would still be in the first rak'ah, making it lengthy}}
\hadithdefcmd{nasai}{974}{أَخْبَرَنِي يَحْيَى بْنُ دُرُسْتَ، قَالَ حَدَّثَنَا أَبُو إِسْمَاعِيلَ، - وَهُوَ الْقَنَّادُ - قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، أَنَّ عَبْدَ اللَّهِ بْنَ أَبِي قَتَادَةَ، حَدَّثَهُ عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ كَانَ يُصَلِّي بِنَا الظُّهْرَ فَيَقْرَأُ فِي الرَّكْعَتَيْنِ الأُولَيَيْنِ يُسْمِعُنَا الآيَةَ كَذَلِكَ وَكَانَ يُطِيلُ الرَّكْعَةَ فِي صَلاَةِ الظُّهْرِ وَالرَّكْعَةَ الأُولَى يَعْنِي فِي صَلاَةِ الصُّبْحِ ‏.‏\hadithno{974}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin Abi Qatadah narrated that:His father said: "The Messenger of Allah (ﷺ) used to lead us in prayer, and he would recite in the first two rak'ahs and make us hear some verses. And he would make the (first) Rak'ah lengthy in Zuhr, and also the first rak'ah." Meaning in Subh}}
\hadithdefcmd{nasai}{975}{أَخْبَرَنَا عِمْرَانُ بْنُ يَزِيدَ بْنِ خَالِدِ بْنِ مُسْلِمٍ، - يُعْرَفُ بِابْنِ أَبِي جَمِيلٍ الدِّمَشْقِيِّ - قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ بْنِ سَمَاعَةَ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي قَتَادَةَ، قَالَ حَدَّثَنَا أَبِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقْرَأُ بِأُمِّ الْقُرْآنِ وَسُورَتَيْنِ فِي الرَّكْعَتَيْنِ الأُولَيَيْنِ مِنْ صَلاَةِ الظُّهْرِ وَصَلاَةِ الْعَصْرِ وَيُسْمِعُنَا الآيَةَ أَحْيَانًا وَكَانَ يُطِيلُ فِي الرَّكْعَةِ الأُولَى ‏.‏\hadithno{975}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah bin Abi Qatadah said:"My father told us that the Messenger of Allah (ﷺ) used to recite Umm Al-Quran and two surahs in the first two rak'ahs of Zuhr and 'Asr, and he would make us hear a verse sometimes, and he used to make the first rak'ah lengthy}}
\hadithdefcmd{nasai}{976}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي قَتَادَةَ، أَنَّ أَبَاهُ، أَخْبَرَهُ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرَأُ بِنَا فِي الرَّكْعَتَيْنِ الأُولَيَيْنِ مِنْ صَلاَةِ الظُّهْرِ وَيُسْمِعُنَا الآيَةَ أَحْيَانًا وَيُطَوِّلُ فِي الأُولَى وَيُقَصِّرُ فِي الثَّانِيَةِ وَكَانَ يَفْعَلُ ذَلِكَ فِي صَلاَةِ الصُّبْحِ يُطَوِّلُ فِي الأُولَى وَيُقَصِّرُ فِي الثَّانِيَةِ وَكَانَ يَقْرَأُ بِنَا فِي الرَّكْعَتَيْنِ الأُولَيَيْنِ مِنْ صَلاَةِ الْعَصْرِ يُطَوِّلُ الأُولَى وَيُقَصِّرُ الثَّانِيَةَ ‏.‏\hadithno{976}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah bin Abi Qatadah narrated that:His father told him: "The Messenger of Allah (ﷺ) used to recite for us in the first two rak'ahs of Zuhr prayer, and he would make us hear a verse sometimes. He would make the first rak'ah longer and the second shorter. And he used to do that in Subh too, make the first rak'ah longer and the second shorter. And he used to recite in the first two rak'ahs of 'Asr prayer, making the first rak'ah longer and the second shorter}}
\hadithdefcmd{nasai}{977}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا أَبَانُ بْنُ يَزِيدَ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرَأُ فِي الظُّهْرِ وَالْعَصْرِ فِي الرَّكْعَتَيْنِ الأُولَيَيْنِ بِأُمِّ الْقُرْآنِ وَسُورَتَيْنِ وَفِي الأُخْرَيَيْنِ بِأُمِّ الْقُرْآنِ وَكَانَ يُسْمِعُنَا الآيَةَ أَحْيَانًا وَكَانَ يُطِيلُ أَوَّلَ رَكْعَةٍ مِنْ صَلاَةِ الظُّهْرِ ‏.‏\hadithno{977}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abdullah bin Abi Qatadah that his father said:"The Messenger of Allah (ﷺ) used to recite the Umm Al-Quran and two surahs in the first two rak'ahs of Zuhr and 'Asr, and in the last two with Umm Al-Quran, and he would make us hear a verse sometimes, and he used to make the first rak'ah lengthy}}
\hadithdefcmd{nasai}{978}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ حَجَّاجٍ الصَّوَّافِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، وَعَنْ أَبِي سَلَمَةَ، عَنْ أَبِي قَتَادَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرَأُ فِي الظُّهْرِ وَالْعَصْرِ فِي الرَّكْعَتَيْنِ الأُولَيَيْنِ بِفَاتِحَةِ الْكِتَابِ وَسُورَتَيْنِ وَيُسْمِعُنَا الآيَةَ أَحْيَانًا وَكَانَ يُطِيلُ الرَّكْعَةَ الأُولَى فِي الظُّهْرِ وَيُقَصِّرُ فِي الثَّانِيَةِ وَكَذَلِكَ فِي الصُّبْحِ ‏.‏\hadithno{978}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Salamah said:"The Messenger of Allah (ﷺ) used to recite the Umm Al-Quran and two surahs in the first two rak'ahs of Zuhr and 'Asr, and he would make us hear a verse sometimes, and he used to make the first rak'ah of zuhr lengthy, and he did likewise in Subh}}
\hadithdefcmd{nasai}{979}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْرَأُ فِي الظُّهْرِ وَالْعَصْرِ بِالسَّمَاءِ ذَاتِ الْبُرُوجِ وَالسَّمَاءِ وَالطَّارِقِ وَنَحْوِهِمَا ‏.‏\hadithno{979}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Jabir bin Samurah that :The Prophet (ﷺ) used to recite "By the heaven holding the big stars" and: "By the heaven, and At-Tariq (the night-comer, i.e. the bright star)" and similar surahs in Zuhr and 'Asr}}
\hadithdefcmd{nasai}{980}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ شُعْبَةَ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقْرَأُ فِي الظُّهْرِ ‏\{‏ وَاللَّيْلِ إِذَا يَغْشَى ‏\}‏ وَفِي الْعَصْرِ نَحْوَ ذَلِكَ وَفِي الصُّبْحِ بِأَطْوَلَ مِنْ ذَلِكَ ‏.‏\hadithno{980}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir bin Samurah said:"The Prophet (ﷺ) used to recite "By the night as it envelops" in Zuhr and something similar in 'Asr, and he would recite something longer than that in subh}}
\hadithdefcmd{nasai}{981}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا الْعَطَّافُ بْنُ خَالِدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، قَالَ دَخَلْنَا عَلَى أَنَسِ بْنِ مَالِكٍ فَقَالَ صَلَّيْتُمْ قُلْنَا نَعَمْ ‏.‏ قَالَ يَا جَارِيَةُ هَلُمِّي لِي وَضُوءًا مَا صَلَّيْتُ وَرَاءَ إِمَامٍ أَشْبَهَ صَلاَةً بِرَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ إِمَامِكُمْ هَذَا ‏.‏ قَالَ زَيْدٌ وَكَانَ عُمَرُ بْنُ عَبْدِ الْعَزِيزِ يُتِمُّ الرُّكُوعَ وَالسُّجُودَ وَيُخَفِّفُ الْقِيَامَ وَالْقُعُودَ ‏.‏\hadithno{981}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Zaid bin Aslam said:"We entered upon Anas bin Malik and he said: 'Have you prayed?' We said: 'Yes.' He asid: 'O slave girl, bring me water for Wudhu! I have never prayed behind any Imam whose prayer more closely resembles the prayer of the Messenger of Allah (ﷺ) than this Imam of yours.'" Zaid said: "Umar bin Abdul Aziz used to complete the bowing and prostration (without rushing) and lighten the standing and sitting}}
\hadithdefcmd{nasai}{982}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ مَا صَلَّيْتُ وَرَاءَ أَحَدٍ أَشْبَهَ صَلاَةً بِرَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ فُلاَنٍ ‏.‏ قَالَ سُلَيْمَانُ كَانَ يُطِيلُ الرَّكْعَتَيْنِ الأُولَيَيْنِ مِنَ الظُّهْرِ وَيُخَفِّفُ الأُخْرَيَيْنِ وَيُخَفِّفُ الْعَصْرَ وَيَقْرَأُ فِي الْمَغْرِبِ بِقِصَارِ الْمُفَصَّلِ وَيَقْرَأُ فِي الْعِشَاءِ بِوَسَطِ الْمُفَصَّلِ وَيَقْرَأُ فِي الصُّبْحِ بِطُوَلِ الْمُفَصَّلِ ‏.‏\hadithno{982}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"I have never prayed behind anyone whose prayer more closely resembled that of the Messenger of Allah (ﷺ) than so-and-so." (The narrator) Sulaiman siad: "He used to make the first two rak'ahs of Zuhr lengthy and the last two shorter, and he would make 'Asr shorter; in Maghrib he would recite the short Mufassal surahs, in Isha' the medium-length Mufassal surahs and in Subh the long Mufassal surahs}}
\hadithdefcmd{nasai}{983}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْحَارِثِ، عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ مَا صَلَّيْتُ وَرَاءَ أَحَدٍ أَشْبَهَ صَلاَةً بِرَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ فُلاَنٍ ‏.‏ فَصَلَّيْنَا وَرَاءَ ذَلِكَ الإِنْسَانِ وَكَانَ يُطِيلُ الأُولَيَيْنِ مِنَ الظُّهْرِ وَيُخَفِّفُ فِي الأُخْرَيَيْنِ وَيُخَفِّفُ فِي الْعَصْرِ وَيَقْرَأُ فِي الْمَغْرِبِ بِقِصَارِ الْمُفَصَّلِ وَيَقْرَأُ فِي الْعِشَاءِ بِالشَّمْسِ وَضُحَاهَا وَأَشْبَاهِهَا وَيَقْرَأُ فِي الصُّبْحِ بِسُورَتَيْنِ طَوِيلَتَيْنِ ‏.‏\hadithno{983}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"I have never prayed behind anyone whose prayer more closely resembled that of the Messenger of Allah (ﷺ) than so-and-so. We prayed behind that person and he used to make the first two rak'ahs of Zuhr lengthy and the last two shorter, and he would make 'Asr shorter; in Maghrib he would recite the short Mufassal surahs. In Isha' he recited: 'By the sun and its brightness and similar surahs, and in subh he recited two lengthy surahs}}
\hadithdefcmd{nasai}{984}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنْ جَابِرٍ، قَالَ مَرَّ رَجُلٌ مِنَ الأَنْصَارِ بِنَاضِحَيْنِ عَلَى مُعَاذٍ وَهُوَ يُصَلِّي الْمَغْرِبَ فَافْتَتَحَ بِسُورَةِ الْبَقَرَةِ فَصَلَّى الرَّجُلُ ثُمَّ ذَهَبَ فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَفَتَّانٌ يَا مُعَاذُ أَفَتَّانٌ يَا مُعَاذُ أَلاَ قَرَأْتَ بِـ ‏\{‏ سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى ‏\}‏ وَالشَّمْسِ وَضُحَاهَا وَنَحْوِهِمَا ‏"‏ ‏.‏\hadithno{984}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Jabir said:"A man from among the Ansar passed Mu'adh leading two camels, when he (Mu'adh) was praying maghrib, and he was starting to recite Al-Baqarah. So that man prayed then went away. News of that reached the Prophet (ﷺ) and he said: 'Do you want to cause hardship to the people, O Mu'adh; do you want to cause hardship to the people, O Mu'adh? Why don't you recite: 'Glorify the Name of your Lord, the Most High' and 'By the sun and its brightness' and the like?}}
\hadithdefcmd{nasai}{985}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا مُوسَى بْنُ دَاوُدَ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ الْمَاجِشُونُ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، عَنْ أُمِّ الْفَضْلِ بِنْتِ الْحَارِثِ، قَالَتْ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي بَيْتِهِ الْمَغْرِبَ فَقَرَأَ الْمُرْسَلاَتِ مَا صَلَّى بَعْدَهَا صَلاَةً حَتَّى قُبِضَ صلى الله عليه وسلم ‏.‏\hadithno{985}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas that Umm Al-Fadl bint Al-Harith said:" The Messenger of Allah (ﷺ) led us in praying maghrib in his house and he recited Al-Mursalat, then after that, he never offered any prayer until he died}}
\hadithdefcmd{nasai}{986}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ أُمِّهِ، أَنَّهَا سَمِعَتِ النَّبِيَّ صلى الله عليه وسلم يَقْرَأُ فِي الْمَغْرِبِ بِالْمُرْسَلاَتِ ‏.‏\hadithno{986}\hadithgrade{Abu Ghuddah: -; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn Abbas from his mother that:She heard the Prophet (ﷺ) recite Al-Mursalat in Maghrib}}
\hadithdefcmd{nasai}{987}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ الزُّهْرِيِّ، عَنْ مُحَمَّدِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقْرَأُ فِي الْمَغْرِبِ بِالطُّورِ ‏.‏\hadithno{987}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Muhammad bin Jubair bin Mut'im that:His father said: "I heard the Prophet (ﷺ) recite At-Tur in Maghrib}}
\hadithdefcmd{nasai}{988}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ الْمُقْرِئُ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا حَيْوَةُ، وَذَكَرَ، آخَرَ قَالاَ حَدَّثَنَا جَعْفَرُ بْنُ رَبِيعَةَ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ هُرْمُزَ، حَدَّثَهُ أَنَّ مُعَاوِيَةَ بْنَ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ حَدَّثَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُتْبَةَ بْنِ مَسْعُودٍ حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَرَأَ فِي صَلاَةِ الْمَغْرِبِ بِـ ‏\{‏ حم ‏\}‏ الدُّخَانِ ‏.‏\hadithno{988}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Mu'awiyah bin Abdullah bin Ja'far narrated that Abdullah bin 'Utbah bin Mas'ud told him that:The Messenger of Allah (ﷺ) recited 'Ha- Mim Ad-Dukhan' in Maghrib}}
\hadithdefcmd{nasai}{989}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ أَبِي الأَسْوَدِ، أَنَّهُ سَمِعَ عُرْوَةَ بْنَ الزُّبَيْرِ، يُحَدِّثُ عَنْ زَيْدِ بْنِ ثَابِتٍ، أَنَّهُ قَالَ لِمَرْوَانَ يَا أَبَا عَبْدِ الْمَلِكِ أَتَقْرَأُ فِي الْمَغْرِبِ بِـ ‏\{‏ قُلْ هُوَ اللَّهُ أَحَدٌ ‏\}‏ وَ ‏\{‏ إِنَّا أَعْطَيْنَاكَ الْكَوْثَرَ ‏\}‏ قَالَ نَعَمْ ‏.‏ قَالَ فَمَحْلُوفَةٌ لَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقْرَأُ فِيهَا بِأَطْوَلِ الطُّولَيَيْنِ ‏\{‏ المص ‏\}‏ ‏.‏\hadithno{989}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Zaid bin Thabit that :He said to Marwan: "O Abu Abdul-Malik, do you recite: 'Say: He is Allah, (the) One' and 'Verily, We have granted you Al-Kawthar' in maghrib?" He said: "Yes." He (Zaid) said: "I swear by Allah, I saw the Messenger of Allah (ﷺ) reciting the longer of the two long surahs in it: 'Alif-Lam-Mim-Sad}}
\hadithdefcmd{nasai}{990}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ مَرْوَانَ بْنَ الْحَكَمِ، أَخْبَرَهُ أَنَّ زَيْدَ بْنَ ثَابِتٍ قَالَ مَا لِي أَرَاكَ تَقْرَأُ فِي الْمَغْرِبِ بِقِصَارِ السُّوَرِ وَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقْرَأُ فِيهَا بِأَطْوَلِ الطُّولَيَيْنِ قُلْتُ يَا أَبَا عَبْدِ اللَّهِ مَا أَطْوَلُ الطُّولَيَيْنِ قَالَ الأَعْرَافُ ‏.‏\hadithno{990}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Marwan bin Al-Hakam narrated that:Zaid bin Thabit said: "Why do I see you reciting short surahs in Maghrib when I saw the Messenger of Allah (ﷺ) reciting the longer of the two long surahs in it?" I said: "O Abu Abdullah, what is the longer of the two long surahs?" He said: "Al-A'raf}}
\hadithdefcmd{nasai}{991}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا بَقِيَّةُ، وَأَبُو حَيْوَةَ عَنِ ابْنِ أَبِي حَمْزَةَ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَرَأَ فِي صَلاَةِ الْمَغْرِبِ بِسُورَةِ الأَعْرَافِ فَرَّقَهَا فِي رَكْعَتَيْنِ ‏.‏\hadithno{991}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Aishah that:The Messenger of Allah (ﷺ) recited Surat Al-A'raf in maghrib and split it between two rak'ahs}}
\hadithdefcmd{nasai}{992}{أَخْبَرَنَا الْفَضْلُ بْنُ سَهْلٍ، قَالَ حَدَّثَنِي أَبُو الْجَوَّابِ، قَالَ حَدَّثَنَا عَمَّارُ بْنُ رُزَيْقٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ إِبْرَاهِيِمَ بْنِ مُهَاجِرٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عُمَرَ، قَالَ رَمَقْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عِشْرِينَ مَرَّةً يَقْرَأُ فِي الرَّكْعَتَيْنِ بَعْدَ الْمَغْرِبِ وَفِي الرَّكْعَتَيْنِ قَبْلَ الْفَجْرِ ‏\{‏ قُلْ يَا أَيُّهَا الْكَافِرُونَ ‏\}‏ وَ ‏\{‏ قُلْ هُوَ اللَّهُ أَحَدٌ ‏\}‏ ‏.‏\hadithno{992}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn Umar said:"I watched the Messenger of Allah (ﷺ)- twenty times- reciting in the two rak'ahs after maghrib 'Say: O you disbelievers' and 'Say: He is Allah, (the) One}}
\hadithdefcmd{nasai}{993}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ، عَنِ ابْنِ وَهْبٍ، قَالَ حَدَّثَنَا عَمْرُو بْنُ الْحَارِثِ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، أَنَّ أَبَا الرِّجَالِ، مُحَمَّدَ بْنَ عَبْدِ الرَّحْمَنِ حَدَّثَهُ عَنْ أُمِّهِ، عَمْرَةَ عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ رَجُلاً عَلَى سَرِيَّةٍ فَكَانَ يَقْرَأُ لأَصْحَابِهِ فِي صَلاَتِهِمْ فَيَخْتِمُ بِـ ‏\{‏ قُلْ هُوَ اللَّهُ أَحَدٌ ‏\}‏ فَلَمَّا رَجَعُوا ذَكَرُوا ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ سَلُوهُ لأَىِّ شَىْءٍ فَعَلَ ذَلِكَ ‏"‏ ‏.‏ فَسَأَلُوهُ فَقَالَ لأَنَّهَا صِفَةُ الرَّحْمَنِ عَزَّ وَجَلَّ فَأَنَا أُحِبُّ أَنْ أَقْرَأَ بِهَا ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَخْبِرُوهُ أَنَّ اللَّهَ عَزَّ وَجَلَّ يُحِبُّهُ ‏"‏ ‏.‏\hadithno{993}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Aishah that:The Messenger of Allah (ﷺ) sent a man on a campaign, and he used to recite to his companions when leading them in prayer, and would conclude with 'Say: He is Allah, (the) One.' When they returned, they told the Messenger of Allah (ﷺ) about that. He said: "Ask them why he did that." So they asked him and he said: "Because it is a description of the Most Merciful, the Mighty and Sublime, and I love to recite it." The Messenger of Allah (ﷺ) said: "Tell him that Allah (SWT), the Mighty and Sublime, loves him}}
\hadithdefcmd{nasai}{994}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عُبَيْدِ بْنِ حُنَيْنٍ، مَوْلَى آلِ زَيْدِ بْنِ الْخَطَّابِ قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ أَقْبَلْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَمِعَ رَجُلاً يَقْرَأُ ‏\{‏ قُلْ هُوَ اللَّهُ أَحَدٌ * اللَّهُ الصَّمَدُ * لَمْ يَلِدْ وَلَمْ يُولَدْ * وَلَمْ يَكُنْ لَهُ كُفُوًا أَحَدٌ ‏\}‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَجَبَتْ ‏"‏ ‏.‏ فَسَأَلْتُهُ مَاذَا يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الْجَنَّةُ ‏"‏ ‏.‏\hadithno{994}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ubaid bin Hunain, the freed slave of the family of Zaib bin Al-Khattab, said:"I heard Abu Hurairah say: 'I came back (from a journey) with the Messenger of Allah (ﷺ) and he heard a man reciting 'Say: He is Allah, (the) One, Allah-us-Samad (the Self-Sufficient Master). He begets not, nor was He begotten. And there is none equal or comparable unto Him.' The Messenger of Allah (ﷺ) said: 'It is guaranteed.' We asked him: 'What, O Messenger of Allah?' He said: 'Paradise}}
\hadithdefcmd{nasai}{995}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي صَعْصَعَةَ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَجُلاً، سَمِعَ رَجُلاً، يَقْرَأُ ‏\{‏ قُلْ هُوَ اللَّهُ أَحَدٌ ‏\}‏ يُرَدِّدُهَا فَلَمَّا أَصْبَحَ جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ إِنَّهَا لَتَعْدِلُ ثُلُثَ الْقُرْآنِ ‏"‏ ‏.‏\hadithno{995}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Sa'eed Al Khudri that:A man heard another man reciting "Say: He is Allah, (the) One" and repeating it. When morning came he went to the Messenger of Allah (ﷺ) and told him about that. The Messenger of Allah (ﷺ) said: "By the One in Whose Hand is my soul, it is equal to one-third of the Quran}}
\hadithdefcmd{nasai}{996}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا زَائِدَةُ، عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ رَبِيعِ بْنِ خُثَيْمٍ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنِ ابْنِ أَبِي لَيْلَى، عَنِ امْرَأَةٍ، عَنْ أَبِي أَيُّوبَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ ‏\{‏ قُلْ هُوَ اللَّهُ أَحَدٌ ‏\}‏ ثُلُثُ الْقُرْآنِ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ مَا أَعْرِفُ إِسْنَادًا أَطْوَلَ مِنْ هَذَا ‏.‏\hadithno{996}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Ayyub that:The Prophet (ﷺ) said: "Say: He is Allah, (the) One" is one-third of the Quran}}
\hadithdefcmd{nasai}{997}{أَخْبَرَنَا مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنْ جَابِرٍ، قَالَ قَامَ مُعَاذٌ فَصَلَّى الْعِشَاءَ الآخِرَةَ فَطَوَّلَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَفَتَّانٌ يَا مُعَاذُ أَفَتَّانٌ يَا مُعَاذُ أَيْنَ كُنْتَ عَنْ ‏\{‏ سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى ‏\}‏ وَالضُّحَى وَ ‏\{‏ إِذَا السَّمَاءُ انْفَطَرَتْ ‏\}‏ ‏"‏ ‏.‏\hadithno{997}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir said:"Muadh stood up and prayed Isha', and made it lengthy. The Prophet (ﷺ) said: 'Do you want to cause hardship to the people, O Mu'adh; do you want to cause hardship to the people O Mu'adh? Why didn't you recite 'Glorify the Name of your Lord Most High' or Ad-Duha or; 'When the heaven is cleft asunder?}}
\hadithdefcmd{nasai}{998}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ صَلَّى مُعَاذُ بْنُ جَبَلٍ لأَصْحَابِهِ الْعِشَاءَ فَطَوَّلَ عَلَيْهِمْ فَانْصَرَفَ رَجُلٌ مِنَّا فَأُخْبِرَ مُعَاذٌ عَنْهُ فَقَالَ إِنَّهُ مُنَافِقٌ ‏.‏ فَلَمَّا بَلَغَ ذَلِكَ الرَّجُلَ دَخَلَ عَلَى النَّبِيِّ صلى الله عليه وسلم فَأَخْبَرَهُ بِمَا قَالَ مُعَاذٌ ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَتُرِيدُ أَنْ تَكُونَ فَتَّانًا يَا مُعَاذُ إِذَا أَمَمْتَ النَّاسَ فَاقْرَأْ بِالشَّمْسِ وَضُحَاهَا وَ ‏\{‏ سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى ‏\}‏ وَ ‏\{‏ وَاللَّيْلِ إِذَا يَغْشَى ‏\}‏ وَ ‏\{‏ اقْرَأْ بِاسْمِ رَبِّكَ ‏\}‏ ‏"‏ ‏.‏\hadithno{998}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:"Mu'adh bin Jabal led his companions in praying Isha' and he made it lengthy. A man left, and Mu'adh was told about that, and he said: 'He is a hypocrite.' When news of that reached the man, he went to the Prophet (ﷺ) and told him what Mu'adh had said. The Prophet (ﷺ) said to him: 'Do you want to be a cause of hardship, O Mu'adh? When you lead the people in prayer, recite 'By the sun and its brightness' and 'Glorify the Name of your Lord, the Most High' and 'By the night as it envelops'and 'Read! In the Name of your Lord}}
\hadithdefcmd{nasai}{999}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَلِيِّ بْنِ الْحَسَنِ بْنِ شَقِيقٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، أَنْبَأَنَا الْحُسَيْنُ بْنُ وَاقِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقْرَأُ فِي صَلاَةِ الْعِشَاءِ الآخِرَةِ بِالشَّمْسِ وَضُحَاهَا وَأَشْبَاهِهَا مِنَ السُّوَرِ ‏.‏\hadithno{999}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abdullah bin Buraidah, from his father, that:The Messenger of Allah (ﷺ) used to recite 'By the sun and its brightness' and similar surahs in Isha}}
\hadithdefcmd{nasai}{1000}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم الْعَتَمَةَ فَقَرَأَ فِيهَا بِالتِّينِ وَالزَّيْتُونِ ‏.‏\hadithno{1000}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Al-Bara' bin Azib said:"I prayed Al-'Atamah (Isha') with the Messenger of Allah (ﷺ) and he recited 'By the gif and the olive' in it}}
\hadithdefcmd{nasai}{1001}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ فَقَرَأَ فِي الْعِشَاءِ فِي الرَّكْعَةِ الأُولَى بِالتِّينِ وَالزَّيْتُونِ ‏.‏\hadithno{1001}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Al-Bara' bin Azib said:"The Messenger of Allah (ﷺ) was on a journey and he recited: 'By the fig and the olive' in the first rak'ah of isha}}
\hadithdefcmd{nasai}{1002}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنِي أَبُو عَوْنٍ، قَالَ سَمِعْتُ جَابِرَ بْنَ سَمُرَةَ، يَقُولُ قَالَ عُمَرُ لِسَعْدٍ قَدْ شَكَاكَ النَّاسُ فِي كُلِّ شَىْءٍ حَتَّى فِي الصَّلاَةِ ‏.‏ فَقَالَ سَعْدٌ أَتَّئِدُ فِي الأُولَيَيْنِ وَأَحْذِفُ فِي الأُخْرَيَيْنِ وَمَا آلُو مَا اقْتَدَيْتُ بِهِ مِنْ صَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ ذَاكَ الظَّنُّ بِكَ ‏.‏\hadithno{1002}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu 'Awn said:"I heard Jabir bin Samurah say: 'Umar said to Sa'eed': "The people are complaining about everything about you, even about your prayer." Sa'd said: "I take my time in the first two rak'ahs and I make the other two shorter. I do my best to follow the example of the Messenger of Allah (ﷺ) in prayer." 'Umar said: 'That is what I thought about you}}
\hadithdefcmd{nasai}{1003}{أَخْبَرَنَا حَمَّادُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ ابْنِ عُلَيَّةَ أَبُو الْحَسَنِ، قَالَ حَدَّثَنَا أَبِي، عَنْ دَاوُدَ الطَّائِيِّ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ وَقَعَ نَاسٌ مِنْ أَهْلِ الْكُوفَةِ فِي سَعْدٍ عِنْدَ عُمَرَ فَقَالُوا وَاللَّهِ مَا يُحْسِنُ الصَّلاَةَ ‏.‏ فَقَالَ أَمَّا أَنَا فَأُصَلِّي بِهِمْ صَلاَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم لاَ أَخْرِمُ عَنْهَا أَرْكُدُ فِي الأُولَيَيْنِ وَأَحْذِفُ فِي الأُخْرَيَيْنِ ‏.‏ قَالَ ذَاكَ الظَّنُّ بِكَ ‏.‏\hadithno{1003}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Jabir bin Samurah said:"Some of the peole of Al-Khufah complained about Sa'd to 'Umar. They said: 'By Allah, he does not pray properly.' He said: 'I lead them in prayer as the Messenger of Allah (ﷺ) did, and I do not deviate from that. I take my time in the first two rak'ahs and make the other two shorter.' He (Umar) said: 'That is what I thought about you}}
\hadithdefcmd{nasai}{1004}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عِيسَى بْنُ يُونُسَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ إِنِّي لأَعْرِفُ النَّظَائِرَ الَّتِي كَانَ يَقْرَأُ بِهِنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم عِشْرِينَ سُورَةً فِي عَشْرِ رَكَعَاتٍ ثُمَّ أَخَذَ بِيَدِ عَلْقَمَةَ فَدَخَلَ ثُمَّ خَرَجَ إِلَيْنَا عَلْقَمَةُ فَسَأَلْنَاهُ فَأَخْبَرَنَا بِهِنَّ ‏.‏\hadithno{1004}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah said:I know the similar surahs that the Messenger of Allah (ﷺ) used to recite, twenty surahs in ten rak'ahs." Then he took 'Alqamah's hand and went in, then 'Alqamah came out and we asked him and he told us what they were}}
\hadithdefcmd{nasai}{1005}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، قَالَ سَمِعْتُ أَبَا وَائِلٍ، يَقُولُ قَالَ رَجُلٌ عِنْدَ عَبْدِ اللَّهِ قَرَأْتُ الْمُفَصَّلَ فِي رَكْعَةٍ ‏.‏ قَالَ هَذًّا كَهَذِّ الشِّعْرِ لَقَدْ عَرَفْتُ النَّظَائِرَ الَّتِي كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرُنُ بَيْنَهُنَّ ‏.‏ فَذَكَرَ عِشْرِينَ سُورَةً مِنَ الْمُفَصَّلِ سُورَتَيْنِ سُورَتَيْنِ فِي رَكْعَةٍ ‏.‏\hadithno{1005}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Amr bin Murrah said:"I heard Abu Wa'il say: "A man said in the presence of Abdullah: 'I recited Al-Mufassal in one rak'ah.' He said: 'That is like reciting poetry. I know the similar surahs that the Messenger of Allah (ﷺ) used to recite together.' And he mentioned twenty surahs from Al-Mufassal, two by two in each rak'ah}}
\hadithdefcmd{nasai}{1006}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ، قَالَ أَنْبَأَنَا إِسْرَائِيلُ، عَنْ أَبِي حَصِينٍ، عَنْ يَحْيَى بْنِ وَثَّابٍ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، وَأَتَاهُ، رَجُلٌ فَقَالَ إِنِّي قَرَأْتُ اللَّيْلَةَ الْمُفَصَّلَ فِي رَكْعَةٍ ‏.‏ فَقَالَ هَذًّا كَهَذِّ الشِّعْرِ لَكِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقْرَأُ النَّظَائِرَ عِشْرِينَ سُورَةً مِنَ الْمُفَصَّلِ مِنْ آلِ حم ‏.‏\hadithno{1006}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Abdullah that:A man came to him and said: "Last night I recited Al-Mufassal in one rak'ah." He said: "That is like reciting poetry. But the Messenger of Allah (ﷺ) used to recite similar surahs, twenty surahs from Al-Mufassal, those that start with Ha-Mim}}
\hadithdefcmd{nasai}{1007}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي مُحَمَّدُ بْنُ عَبَّادٍ، حَدِيثًا رَفَعَهُ إِلَى ابْنِ سُفْيَانَ عَنْ عَبْدِ اللَّهِ بْنِ السَّائِبِ، قَالَ حَضَرْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَوْمَ الْفَتْحِ فَصَلَّى فِي قُبُلِ الْكَعْبَةِ فَخَلَعَ نَعْلَيْهِ فَوَضَعَهُمَا عَنْ يَسَارِهِ فَافْتَتَحَ بِسُورَةِ الْمُؤْمِنِينَ فَلَمَّا جَاءَ ذِكْرُ مُوسَى أَوْ عِيسَى - عَلَيْهِمَا السَّلاَمُ - أَخَذَتْهُ سَعْلَةٌ فَرَكَعَ ‏.‏\hadithno{1007}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abdullah bin As-Sa'ib said:"I was with the Messenger of Allah (ﷺ) on the day of the Conquest (of Makkah). He prayed in front of the Ka'bah. He took off his shoes and placed them to his left, and he started to recite Surat Al-Mu'minun. When he reached the passage that mentions Musa and 'Eisa, peace be upon them both, he started coughing, then he bowed}}
\hadithdefcmd{nasai}{1008}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى، وَعَبْدُ الرَّحْمَنِ، وَابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنِ الْمُسْتَوْرِدِ بْنِ الأَحْنَفِ، عَنْ صِلَةَ بْنِ زُفَرَ، عَنْ حُذَيْفَةَ، أَنَّهُ صَلَّى إِلَى جَنْبِ النَّبِيِّ صلى الله عليه وسلم لَيْلَةً فَقَرَأَ فَكَانَ إِذَا مَرَّ بِآيَةِ عَذَابٍ وَقَفَ وَتَعَوَّذَ وَإِذَا مَرَّ بِآيَةِ رَحْمَةٍ وَقَفَ فَدَعَا وَكَانَ يَقُولُ فِي رُكُوعِهِ ‏"‏ سُبْحَانَ رَبِّيَ الْعَظِيمِ ‏"‏ ‏.‏ وَفِي سُجُودِهِ ‏"‏ سُبْحَانَ رَبِّيَ الأَعْلَى ‏"‏ ‏.‏\hadithno{1008}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Hudhaifah that:He prayed beside the Prophet (ﷺ) one night. He recited, and when he came to a verse that mentioned punishment, he would pause and seek refuge with Allah; if he came to a verse that mentioned mercy, he would pause for mercy. In his bowing he would say: 'Subhana Rabbil-Azim (Glory be to my Lord Almighty)' and in his prostration he would say: 'Subhan Rabbil-A'la (Glory be to my Lord the Most High)}}
\hadithdefcmd{nasai}{1009}{أَخْبَرَنَا مُحَمَّدُ بْنُ آدَمَ، عَنْ حَفْصِ بْنِ غِيَاثٍ، عَنِ الْعَلاَءِ بْنِ الْمُسَيَّبِ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ طَلْحَةَ بْنِ يَزِيدَ، عَنْ حُذَيْفَةَ، وَالأَعْمَشِ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنِ الْمُسْتَوْرِدِ بْنِ الأَحْنَفِ، عَنْ صِلَةَ بْنِ زُفَرَ، عَنْ حُذَيْفَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَرَأَ الْبَقَرَةَ وَآلَ عِمْرَانَ وَالنِّسَاءَ فِي رَكْعَةٍ لاَ يَمُرُّ بِآيَةِ رَحْمَةٍ إِلاَّ سَأَلَ وَلاَ بِآيَةِ عَذَابٍ إِلاَّ اسْتَجَارَ ‏.‏\hadithno{1009}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Hudhaifah that:The Prophet (ﷺ) recited Surat Al-Baqarah, Al 'Imran and An-Nisa' in one rak'ah, and he did not reach any verse that spoke of mercy but he asked Allah for it, nor any verse that spoke of punishment but he asked Allah for protection therefrom}}
\hadithdefcmd{nasai}{1010}{أَخْبَرَنَا نُوحُ بْنُ حَبِيبٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، قَالَ حَدَّثَنَا قُدَامَةُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَتْنِي جَسْرَةُ بِنْتُ دَجَاجَةَ، قَالَتْ سَمِعْتُ أَبَا ذَرٍّ، يَقُولُ قَامَ النَّبِيُّ صلى الله عليه وسلم حَتَّى أَصْبَحَ بِآيَةٍ وَالآيَةُ ‏\{‏ إِنْ تُعَذِّبْهُمْ فَإِنَّهُمْ عِبَادُكَ وَإِنْ تَغْفِرْ لَهُمْ فَإِنَّكَ أَنْتَ الْعَزِيزُ الْحَكِيمُ ‏\}‏ ‏.‏\hadithno{1010}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Jasrah bint Dijajah said:"I heard Abu Dharr say: 'The Prophet (ﷺ) stayed up all night repeating one verse. The verse was: 'If You punish them, they are Your slaves, and if You forgive them, verily, You, only You, are the All-Mighty, the All-Wise}}
\hadithdefcmd{nasai}{1011}{أَخْبَرَنَا أَحْمَدُ بْنُ مَنِيعٍ، وَيَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، قَالاَ حَدَّثَنَا هُشَيْمٌ، قَالَ حَدَّثَنَا أَبُو بِشْرٍ، جَعْفَرُ بْنُ أَبِي وَحْشِيَّةَ - وَهُوَ ابْنُ إِيَاسٍ - عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، فِي قَوْلِهِ عَزَّ وَجَلَّ ‏\{‏ وَلاَ تَجْهَرْ بِصَلاَتِكَ وَلاَ تُخَافِتْ بِهَا ‏\}‏ قَالَ نَزَلَتْ وَرَسُولُ اللَّهِ صلى الله عليه وسلم مُخْتَفٍ بِمَكَّةَ فَكَانَ إِذَا صَلَّى بِأَصْحَابِهِ رَفَعَ صَوْتَهُ - وَقَالَ ابْنُ مَنِيعٍ يَجْهَرُ بِالْقُرْآنِ - وَكَانَ الْمُشْرِكُونَ إِذَا سَمِعُوا صَوْتَهُ سَبُّوا الْقُرْآنَ وَمَنْ أَنْزَلَهُ وَمَنْ جَاءَ بِهِ فَقَالَ اللَّهُ عَزَّ وَجَلَّ لِنَبِيِّهِ صلى الله عليه وسلم ‏\{‏ وَلاَ تَجْهَرْ بِصَلاَتِكَ ‏\}‏ أَىْ بِقِرَاءَتِكَ فَيَسْمَعُ الْمُشْرِكُونَ فَيَسُبُّوا الْقُرْآنَ ‏\{‏ وَلاَ تُخَافِتْ بِهَا ‏\}‏ عَنْ أَصْحَابِكَ فَلاَ يَسْمَعُوا ‏\{‏ وَابْتَغِ بَيْنَ ذَلِكَ سَبِيلاً ‏\}‏ ‏.‏\hadithno{1011}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:Concerning the saying of Allah, the Mighty and Sublime: "And offer your salah (prayer) neither aloud nor in a low voice"- It was revealed when the Messenger of Allah (ﷺ) was still (preaching) in secret in Makkah. When he led his companions in prayer, he would raise his voice" -(One of the narrators) Ibn Mani' said: He would recite the Quran out loud"- "And when the idolators heard his voice they would insult the Quran, and the One Who revealed it, and the one who brought it. So Allah, the Mighty and Sublime, said to His Prophet (ﷺ): And offer your salah (prayer) neither aloud that is, such that the idolators can hear your recitation and insult the Quran; nor in a low voice, so that your companions cannot hear; but follow a way between}}
\hadithdefcmd{nasai}{1012}{أَخْبَرَنَا مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ جَعْفَرِ بْنِ إِيَاسٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَرْفَعُ صَوْتَهُ بِالْقُرْآنِ وَكَانَ الْمُشْرِكُونَ إِذَا سَمِعُوا صَوْتَهُ سَبُّوا الْقُرْآنَ وَمَنْ جَاءَ بِهِ فَكَانَ النَّبِيُّ صلى الله عليه وسلم يَخْفِضُ صَوْتَهُ بِالْقُرْآنِ مَا كَانَ يَسْمَعُهُ أَصْحَابُهُ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَلاَ تَجْهَرْ بِصَلاَتِكَ وَلاَ تُخَافِتْ بِهَا وَابْتَغِ بَيْنَ ذَلِكَ سَبِيلاً ‏\}‏ ‏"‏ ‏.‏\hadithno{1012}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn Abbas said:"The Prophet (ﷺ) used to raise his voice when reciting Quran, and when the idolaters heard his voice they would insult the Quran and the one who had brought it. So the Prophet (ﷺ) began to lower his voice such that his companions would not hear him. Then Allah (SWT), the Mighty and Sublime, revealed: 'And offer your salah (prayer) neither aloud nor in a low voice, but follow a way between}}
\hadithdefcmd{nasai}{1013}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، عَنْ وَكِيعٍ، قَالَ حَدَّثَنَا مِسْعَرٌ، عَنْ أَبِي الْعَلاَءِ، عَنْ يَحْيَى بْنِ جَعْدَةَ، عَنْ أُمِّ هَانِئٍ، قَالَتْ كُنْتُ أَسْمَعُ قِرَاءَةَ النَّبِيِّ صلى الله عليه وسلم وَأَنَا عَلَى عَرِيشِي ‏.‏\hadithno{1013}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Umm Hani said:"I used to listen to the Prophet (ﷺ) reciting Quran when I was on my roof}}
\hadithdefcmd{nasai}{1014}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ قَتَادَةَ، قَالَ سَأَلْتُ أَنَسًا كَيْفَ كَانَتْ قِرَاءَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ كَانَ يَمُدُّ صَوْتَهَ مَدًّا ‏.‏\hadithno{1014}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Qatadah said:"I asked Anas: 'How did the Messenger of Allah (ﷺ) recite Quran?' He said: 'He used to elongate the sounds}}
\hadithdefcmd{nasai}{1015}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ طَلْحَةَ بْنِ مُصَرِّفٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْسَجَةَ، عَنِ الْبَرَاءِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ زَيِّنُوا الْقُرْآنَ بِأَصْوَاتِكُمْ ‏"‏ ‏.‏\hadithno{1015}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Bara' said:"The Messenger of Allah (ﷺ) said: 'Make your voices beautiful when you recite Quran}}
\hadithdefcmd{nasai}{1016}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنِي طَلْحَةُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْسَجَةَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ زَيِّنُوا الْقُرْآنَ بِأَصْوَاتِكُمْ ‏"‏ ‏.‏ قَالَ ابْنُ عَوْسَجَةَ كُنْتُ نَسِيتُ هَذِهِ ‏"‏ زَيِّنُوا الْقُرْآنَ ‏"‏ ‏.‏ حَتَّى ذَكَّرَنِيهِ الضَّحَّاكُ بْنُ مُزَاحِمٍ ‏.‏\hadithno{1016}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Al-Bara' bin Azib said:"The Messenger of Allah (ﷺ) said: 'Make your voices beautiful when you recite Quran}}
\hadithdefcmd{nasai}{1017}{أَخْبَرَنَا مُحَمَّدُ بْنُ زُنْبُورٍ الْمَكِّيُّ، قَالَ حَدَّثَنَا ابْنُ أَبِي حَازِمٍ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا أَذِنَ اللَّهُ لِشَىْءٍ مَا أَذِنَ لِنَبِيٍّ حَسَنِ الصَّوْتِ يَتَغَنَّى بِالْقُرْآنِ يَجْهَرُ بِهِ ‏"‏ ‏.‏\hadithno{1017}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that:He heard the Messenger of Allah (ﷺ) say: "Allah never listens to anything as He listens to a Prophet with a beautiful voice chanting the Quran aloud}}
\hadithdefcmd{nasai}{1018}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا أَذِنَ اللَّهُ عَزَّ وَجَلَّ لِشَىْءٍ يَعْنِي أَذَنَهُ لِنَبِيٍّ يَتَغَنَّى بِالْقُرْآنِ ‏"‏ ‏.‏\hadithno{1018}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet (ﷺ) said: "Allah, the Mighty and Sublime, never listens to anything as He listens to a Prophet chanting the Quran}}
\hadithdefcmd{nasai}{1019}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، أَنَّ ابْنَ شِهَابٍ، أَخْبَرَهُ أَنَّ أَبَا سَلَمَةَ أَخْبَرَهُ أَنَّ أَبَا هُرَيْرَةَ حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سَمِعَ قِرَاءَةَ أَبِي مُوسَى فَقَالَ ‏ "‏ لَقَدْ أُوتِيَ مِزْمَارًا مِنْ مَزَامِيرِ آلِ دَاوُدَ عَلَيْهِ السَّلاَمُ ‏"‏ ‏.‏\hadithno{1019}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah narrated that:The Messenger of Allah (ﷺ) heard the recitation of Abu Musa and said: He has been given a Mizmar among the Mazamir of the family of Dawud, peace be upon him}}
\hadithdefcmd{nasai}{1020}{أَخْبَرَنَا عَبْدُ الْجَبَّارِ بْنُ الْعَلاَءِ بْنِ عَبْدِ الْجَبَّارِ، عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ سَمِعَ النَّبِيُّ صلى الله عليه وسلم قِرَاءَةَ أَبِي مُوسَى فَقَالَ ‏ "‏ لَقَدْ أُوتِيَ هَذَا مِنْ مَزَامِيرِ آلِ دَاوُدَ عَلَيْهِ السَّلاَمُ ‏"‏ ‏.‏\hadithno{1020}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) heard the recitation of Abu Musa and said: 'This man has been given a Mizmar among the Mazamir of the family of Dawud, peace be upon him}}
\hadithdefcmd{nasai}{1021}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ سَمِعَ رَسُولُ اللَّهِ صلى الله عليه وسلم قِرَاءَةَ أَبِي مُوسَى فَقَالَ ‏ "‏ لَقَدْ أُوتِيَ هَذَا مِزْمَارًا مِنْ مَزَامِيرِ آلِ دَاوُدَ عَلَيْهِ السَّلاَمُ ‏"‏ ‏.‏\hadithno{1021}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) heard the recitation of Abu Musa and said: 'This man has been given a Mizmar among the Mazamir of the family of Dawud, peace be upon him}}
\hadithdefcmd{nasai}{1022}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، عَنْ يَعْلَى بْنِ مَمْلَكٍ، أَنَّهُ سَأَلَ أُمَّ سَلَمَةَ عَنْ قِرَاءَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم وَصَلاَتِهِ قَالَتْ مَا لَكُمْ وَصَلاَتَهُ ثُمَّ نَعَتَتْ فَإِذَا هِيَ تَنْعَتُ قِرَاءَتَهُ مُفَسَّرَةً حَرْفًا حَرْفًا ‏.‏\hadithno{1022}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ya'la bin Mamlak that :He asked Umm Salamah about the recitation and prayer of the Messenger of Allah (ﷺ) and she said: "Why do you want to know about his prayer?" Then she described his recitation and as being so measured and clear that each letter could be distinguished}}
\hadithdefcmd{nasai}{1023}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، حِينَ اسْتَخْلَفَهُ مَرْوَانُ عَلَى الْمَدِينَةِ كَانَ إِذَا قَامَ إِلَى الصَّلاَةِ الْمَكْتُوبَةِ كَبَّرَ ثُمَّ يُكَبِّرُ حِينَ يَرْكَعُ فَإِذَا رَفَعَ رَأْسَهُ مِنَ الرَّكْعَةِ قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ رَبَّنَا وَلَكَ الْحَمْدُ ثُمَّ يُكَبِّرُ حِينَ يَهْوِي سَاجِدًا ثُمَّ يُكَبِّرُ حِينَ يَقُومُ مِنَ الثِّنْتَيْنِ بَعْدَ التَّشَهُّدِ يَفْعَلُ مِثْلَ ذَلِكَ حَتَّى يَقْضِيَ صَلاَتَهُ فَإِذَا قَضَى صَلاَتَهُ وَسَلَّمَ أَقْبَلَ عَلَى أَهْلِ الْمَسْجِدِ فَقَالَ وَالَّذِي نَفْسِي بِيَدِهِ إِنِّي لأَشْبَهُكُمْ صَلاَةً بِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1023}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Salamah bin Abdur-Rahman that:Marwan appointed Abu Hurairah as governor of Al-Madinah. When he stood to offer an obligatory prayer, he would say the takbir, then he said the takbir when he bowed, and when he raised his head from bowing he said: "Sami' Allahu liman hamidah, Rabbana wa lakal-hamd (Allah hears those who praise Him; our Lord, and to You be the praise)." Then he would say the takbir when he went down in prostration, then he said the takbir when he stood up after two rak'ahs, after saying the Tashahhud, and he did that until he had finished the prayer. When he had finished his prayer and said the Salam, he turned to the people in the masjid and said: "By the One in Whose Hand is my soul, I am the one among you whose prayer most closely resembles that of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{nasai}{1024}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ نَصْرِ بْنِ عَاصِمٍ اللَّيْثِيِّ، عَنْ مَالِكِ بْنِ الْحُوَيْرِثِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَرْفَعُ يَدَيْهِ إِذَا كَبَّرَ وَإِذَا رَكَعَ وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ حَتَّى بَلَغَتَا فُرُوعَ أُذُنَيْهِ ‏.‏\hadithno{1024}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Malik bin Al-Huwairith said:"I saw the Messenger of Allah (ﷺ) raise his hands until they reached the highest part of his ears, when he said the takbir, when he bowed and when he raised his head from bowing}}
\hadithdefcmd{nasai}{1025}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم إِذَا افْتَتَحَ الصَّلاَةَ يَرْفَعُ يَدَيْهِ حَتَّى يُحَاذِيَ مَنْكِبَيْهِ وَإِذَا رَكَعَ وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ ‏.‏\hadithno{1025}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Salim that:His father said: "I saw the Messenger of Allah (ﷺ) when he started to pray, raise his hands until they were parallel to his shoulders, (and he did that) when he bowed and when he raised his head from bowing}}
\hadithdefcmd{nasai}{1026}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ سُفْيَانَ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ أَلاَ أُخْبِرُكُمْ بِصَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ فَقَامَ فَرَفَعَ يَدَيْهِ أَوَّلَ مَرَّةٍ ثُمَّ لَمْ يُعِدْ ‏.‏\hadithno{1026}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Alqamah, that Abdullah said:"Shall I not tell you about the prayer of the Messenger of Allah (ﷺ)? He stood and raised his hands the first time and then he did not do that again}}
\hadithdefcmd{nasai}{1027}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا الْفُضَيْلُ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ أَبِي مَعْمَرٍ، عَنْ أَبِي مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُجْزِئُ صَلاَةٌ لاَ يُقِيمُ الرَّجُلُ فِيهَا صُلْبَهُ فِي الرُّكُوعِ وَالسُّجُودِ ‏"‏ ‏.‏\hadithno{1027}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Mas'ud said:"The Messenger of Allah (ﷺ) said: 'The prayer is not valid if a man does not bring his backbone to rest while bowing and prostrating}}
\hadithdefcmd{nasai}{1028}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، وَحَمَّادِ بْنِ سَلَمَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اعْتَدِلُوا فِي الرُّكُوعِ وَالسُّجُودِ وَلاَ يَبْسُطْ أَحَدُكُمْ ذِرَاعَيْهِ كَالْكَلْبِ ‏"‏ ‏.‏\hadithno{1028}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas that the Messenger of Allah (ﷺ) said:"Be moderate in bowing and prostration, and do not rest your forearms along the ground like a dog}}
